use Test::More tests => 8;
use strict;
use Config;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::Error qw( ExistsError );
use DE_EPAGES::Core::API::InlineJavaServer qw( ExistsRunningInlineJavaServer StartInlineJavaServer StopInlineJavaServer RestartInlineJavaServer GetInlineJavaConfig CreateJavaObject );

RunScript( Sub => sub {

    StopInlineJavaServer();

    #Test Config
    my $hConfig = GetInlineJavaConfig();
    my $ConfigValues =    $hConfig->{'BIND'}
                       and $hConfig->{'HOST'}
                       and $hConfig->{'PORT'}
                       and $hConfig->{'J2SDK'}
                       and $hConfig->{'DIRECTORY'}
                       and $hConfig->{'STARTUP_DELAY'}
                       and $hConfig->{'EXTRA_JAVA_ARGS'}
                       ? 1 : 0;
    ok( $ConfigValues, "config values." );

    #Start server.. Is it running?
    StartInlineJavaServer();
    ok( ExistsRunningInlineJavaServer(), "server is running" );

    #Stop server.. Is it running?
    StopInlineJavaServer();
    ok( !ExistsRunningInlineJavaServer(), "server is not running" );

    #Create java object.. server should start automatically!
    my @Params = ('bla', 'bli', 'blubb');
    my $TestObj = CreateJavaObject({
        'ClassName' => 'JavaServerTest',
        'ClassPath' => $ENV{'EPAGES_CARTRIDGES'}. '/DE_EPAGES/Core/t/JavaLib/JavaServerTest.jar',
        'Params'    => [ \@Params ]
    });
    isa_ok( $TestObj, 'main::JavaServerTest' );

    #Call a method
    my $Item = eval { $TestObj->getItem(2) };
    ok(!ExistsError(), "no errors");
    is($Item, $Params[2], "call object method");

    #Restart server.
    my $PID_0 = GetJavaPID($hConfig);
    my $Time_0 = time;

    RestartInlineJavaServer();

    my $Time_1 = time;
    my $TimeDiff = $Time_1 - $Time_0;
    my $PID_1 = GetJavaPID($hConfig);
    my $Debug = "PID_0: $PID_0 - PID_1: $PID_1 need: $TimeDiff seconds";

    ok(ExistsRunningInlineJavaServer(), "server is running after restart - $Debug");
    isnt($PID_0, $PID_1, "server restarted - $Debug");

    StopInlineJavaServer();

});

sub GetJavaPID {
    my ($hConfig) = @_;
    my $JavaPID = undef;

    if($Config{'osname'} eq 'MSWin32') {
        my @ProcessList = `netstat -no`;
        $JavaPID = (grep {/\s*tcp\s*\S*\:$hConfig->{PORT}/i} @ProcessList)[0];
    } else {
        my @ProcessList = `netstat -nlept`;
        $JavaPID = (grep {/\s*tcp.*\:$hConfig->{PORT}/i} @ProcessList)[0];
    }
    $JavaPID =~ s/.*\s(\d+).*$/$1/ if defined $JavaPID;

    return $JavaPID;
}
