use strict;

use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::WebService::API::Client;
use SOAP::Lite;
use Test::More;

#--------------------------------------------------------------------------------------
sub testSOAPClient_ShoppingCartValidate {
    my $oS = DE_EPAGES::WebService::API::Client->proxy('https://secure.micromata.de/popweb/gw/ws/SoapConnector')
      ->uri('https://www.dhl.de/popweb/gw/ws/schema/1.0/popsp')->encodingStyle('')->autotype(0)->soapversion('1.1')->readable(1);

    my $SenderAddress = SOAP::Data->attr( {
            'name1'       => 'Jan F.J. Spanier',
            'name2'       => 'ePages GmbH',
            'street'      => 'Pilatuspool',
            'houseNumber' => '2',
            'postalCode'  => '20355',
            'city'        => 'Hamburg',
            'countryCode' => 'DEU',
            'email'       => 'jspanier@epages.com',
            'phoneNumber' => '+49 40 350188241',
        }
    )->type('popsc:BaseLabelAddressType')->name('popsc:SenderAddress');

    my $ReceiverAddress = SOAP::Data->attr( {
            'name1'       => 'Max Mustermann',
            'name2'       => 'Mustermann GmbH',
            'street'      => 'Musterstrasse',
            'houseNumber' => '1',
            'postalCode'  => '12345',
            'city'        => 'Mnster',
            'countryCode' => 'DEU',
            'email'       => 'max@mustermann.de',
            'phoneNumber' => '+49 40 123456789',
        }
    )->type('popsc:BaseLabelAddressType')->name('popsc:ReceiverAddress');

    my $LabelItem = SOAP::Data->attr( { 'productId' => 'PAK10.DEU', } )->type('popsc:LabelItemType')
      ->name( 'popsc:LabelItem' => \SOAP::Data->value( $SenderAddress, $ReceiverAddress, ) );

    my $Orderer = SOAP::Data->attr( {
            'name1'       => 'Max Mustermann',
            'name2'       => 'Mustermann GmbH',
            'street'      => 'Musterstrasse',
            'houseNumber' => '1',
            'postalCode'  => '12345',
            'city'        => 'Mnster',
            'countryCode' => 'DEU',
            'email'       => 'max@mustermann.de',
            'phoneNumber' => '+49 40 123456789',
        }
    )->type('popsc:BaseLabelAddressType')->name('popsc:Orderer');

    my $PaymentPartner = SOAP::Data->attr( { 'paymentId' => 'DUMMYPAY', } )->type('popsc:PaymentPartnerpayType')->name('popsc:PaymentPartner');

    my $ShoppingCart = SOAP::Data->attr( { 'acceptAgb' => 'true', } )->type('popsc:BuyShoppingCartType')
      ->name( 'popws:ShoppingCart' => \SOAP::Data->value( $Orderer, $LabelItem, $PaymentPartner, ) );

    my $Auth = SOAP::Data->attr( {
            'partnerId'    => 'DHLANON',
            'subPartnerId' => 'UnitTest',
            'user'         => 'wsumaptostester',
            'password'     => 'mawstest',
        }
    )->type('popws:AuthType')->name('popws:Auth');

    my $ShoppingCartValidateRequest = SOAP::Data->attr( {
            'xmlns:popws' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popws',
            'xmlns:popsc' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popsc',
            'version'     => '1.0.0',
        }
    )->type('popws:ShoppingCartValidateRequestType')->name('popws:ShoppingCartValidateRequest');

    my $rSub = sub {
        my $ret = $oS->call( $ShoppingCartValidateRequest, SOAP::Data->value( $Auth, $ShoppingCart, ) );
        return $ret;
    };

    my $ret = $oS->logCommunication( 'DHLDebug', $rSub );

    my $ResponseStatus = $ret->dataof('//ShoppingCartValidateResponse/Status')->attr->{'status'};

    if ( $ResponseStatus == 0 ) {
        pass('test SOAPClient_ShoppingCartValidate' );
    }
    else {
        my $ErrorMessage = $ret->dataof('//ShoppingCartValidateResponse/Status')->attr->{'errorMessage'};
        fail('test SOAPClient_ShoppingCartValidate - ErrorMessage: ' . $ErrorMessage );
    }

}

#--------------------------------------------------------------------------------------
sub testSOAPClient_ShoppingCartCheckoutViaPayment {
    my $oS = DE_EPAGES::WebService::API::Client->proxy('https://secure.micromata.de/popweb/gw/ws/SoapConnector')
      ->uri('https://www.dhl.de/popweb/gw/ws/schema/1.0/popsp')->encodingStyle('')->autotype(0)->soapversion('1.1')->readable(1);

    my $PartnerBackLinks = SOAP::Data->attr( {
            'paymentAcceptedUrl' => 'https://shoppingcart.partnerxy.de/a/b/c/PartnerDownloadgspt?accepted=true',
            'paymentRejectedUrl' => 'https://shoppingcart.partnerxy.de/a/b/c/PartnerDownloadgspt?accepted=false',
        }
    )->type('popws:PartnerBackLinksType')->name('popws:PartnerBackLinks');

    my $SenderAddress = SOAP::Data->attr( {
            'name1'       => 'Jan F.J. Spanier',
            'name2'       => 'ePages GmbH',
            'street'      => 'Pilatuspool',
            'houseNumber' => '2',
            'postalCode'  => '20355',
            'city'        => 'Hamburg',
            'countryCode' => 'DEU',
            'email'       => 'jspanier@epages.com',
            'phoneNumber' => '+49 40 350188241',
        }
    )->type('popsc:BaseLabelAddressType')->name('popsc:SenderAddress');

    my $ReceiverAddress = SOAP::Data->attr( {
            'name1'       => 'Max Mustermann',
            'name2'       => 'Mustermann GmbH',
            'street'      => 'Musterstrasse',
            'houseNumber' => '1',
            'postalCode'  => '12345',
            'city'        => 'Mnster',
            'countryCode' => 'DEU',
            'email'       => 'max@mustermann.de',
            'phoneNumber' => '+49 40 123456789',
        }
    )->type('popsc:BaseLabelAddressType')->name('popsc:ReceiverAddress');

    my $LabelItem = SOAP::Data->attr( { 'productId' => 'PAK10.DEU', } )->type('popsc:LabelItemType')
      ->name( 'popsc:LabelItem' => \SOAP::Data->value( $SenderAddress, $ReceiverAddress, ) );

    my $Orderer = SOAP::Data->attr( {
            'name1'       => 'Max Mustermann',
            'name2'       => 'Mustermann GmbH',
            'street'      => 'Musterstrasse',
            'houseNumber' => '1',
            'postalCode'  => '12345',
            'city'        => 'Mnster',
            'countryCode' => 'DEU',
            'email'       => 'max@mustermann.de',
            'phoneNumber' => '+49 40 123456789',
        }
    )->type('popsc:BaseLabelAddressType')->name('popsc:Orderer');

    my $PaymentPaypal = SOAP::Data->type('popsc:PaymentPaypalType')->name('popsc:PaymentPaypal');

    my $BuyShoppingCart = SOAP::Data->attr( { 'acceptAgb' => 'true', } )->type('popsc:BuyShoppingCartType')
      ->name( 'popws:BuyShoppingCart' => \SOAP::Data->value( $Orderer, $LabelItem, $PaymentPaypal, ) );

    my $Auth = SOAP::Data->attr( {
            'partnerId'    => 'DHLANON',
            'subPartnerId' => 'UnitTest',
            'user'         => 'wsumaptostester',
            'password'     => 'mawstest',
        }
    )->type('popws:AuthType')->name('popws:Auth');

    my $ShoppingCartCheckoutViaPaymentRequest = SOAP::Data->attr( {
            'xmlns:popps' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popps',
            'xmlns:popws' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popws',
            'xmlns:popsc' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popsc',
            'version'     => '1.0.0',
        }
    )->type('popws:ShoppingCartCheckoutViaPaymentRequestType')->name('popws:ShoppingCartCheckoutViaPaymentRequest');

    my $rSub = sub {
        my $ret = $oS->call( $ShoppingCartCheckoutViaPaymentRequest, SOAP::Data->value( $Auth, $BuyShoppingCart, $PartnerBackLinks, ) );
        return $ret;
    };

    my $ret = $oS->logCommunication( 'DHLDebug', $rSub );

    my $ResponseStatus = $ret->dataof('//ShoppingCartCheckoutViaPaymentResponse/Status')->attr->{'status'};

    if ( $ResponseStatus == 0 ) {
        pass('test SOAPClient_ShoppingCartCheckoutViaPayment' );
    }
    else {
        my $ErrorMessage = $ret->dataof('//ShoppingCartCheckoutViaPaymentResponse/Status')->attr->{'errorMessage'};
        fail('test SOAPClient_ShoppingCartCheckoutViaPayment - ErrorMessage: ' . $ErrorMessage );
    }

}

#--------------------------------------------------------------------------------------
sub testSOAPClient_LoadBuyedShoppingCart {
    my $oS = DE_EPAGES::WebService::API::Client->proxy('https://secure.micromata.de/popweb/gw/ws/SoapConnector')
      ->uri('https://www.dhl.de/popweb/gw/ws/schema/1.0/popsp')->encodingStyle('')->autotype(0)->soapversion('1.1')->readable(1);

    my $ShoppingCartIdentification
      = SOAP::Data->attr( { 'shoppingCartId' => 'EZNSHRBU8', } )->type('popsc:sc:ShoppingCartIdentificationType')->name('popws:ShoppingCartIdentification');

    my $Auth = SOAP::Data->attr( {
            'partnerId'    => 'DHLANON',
            'subPartnerId' => 'UnitTest',
            'user'         => 'wsumaptostester',
            'password'     => 'mawstest',
        }
    )->type('popws:AuthType')->name('popws:Auth');

    my $LoadBuyedShoppingCartRequest = SOAP::Data->attr( {
            'xmlns:popps' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popps',
            'xmlns:popws' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popws',
            'xmlns:popsc' => 'https://www.dhl.de/popweb/gw/ws/schema/1.0/popsc',
            'version'     => '1.0.0',
        }
    )->type('popws:LoadBuyedShoppingCartRequestType')->name('popws:LoadBuyedShoppingCartRequest');

    my $rSub = sub {
        my $ret = $oS->call( $LoadBuyedShoppingCartRequest, SOAP::Data->value( $Auth, $ShoppingCartIdentification, ) );
        return $ret;
    };

    my $ret = $oS->logCommunication( 'DHLDebug', $rSub );

    my $ResponseStatus = $ret->dataof('//LoadBuyedShoppingCartResponse/Status')->attr->{'status'};

    if ( $ResponseStatus == 0 ) {
        pass('test SOAPClient_LoadBuyedShoppingCart' );
    }
    else {
        my $ErrorMessage = $ret->dataof('//LoadBuyedShoppingCartResponse/Status')->attr->{'errorMessage'};
        fail('test SOAPClient_LoadBuyedShoppingCart - ErrorMessage: ' . $ErrorMessage );
    }

}

#--------------------------------------------------------------------------------------
RunScript(
    'Sub' => sub {
        pass('test started' );

        eval {
            testSOAPClient_ShoppingCartValidate;
            testSOAPClient_ShoppingCartCheckoutViaPayment;
            testSOAPClient_LoadBuyedShoppingCart;
        };
        if ( ExistsError() ) {
            my $Error = GetError();
            if ( $Error->shortMessage =~ /500 SSL read timeout/ ) {
                note( 'caught from time to time occurring SSL read timeout and ignore it: ' . $Error->shortMessage() );
            } elsif ( $Error->shortMessage =~ /404 Not Found/ ) {
                note( 'caught from time to time occurring 404 not found and ignore it: ' . $Error->shortMessage() );
            } else {
                fail( $Error->longMessage() );
            }
        }

        done_testing();
        return;
      }

);
