/*  EPages JavaScript module, $Revision: 1.84.2.6 $
 *  (c) 2006 ePages GmbH
 *--------------------------------------------------------------------------*/
dojo.provide("epages.epages");

(function() {
	// is this called in an iframe?
	// these vars are set, when epages is loaded in an iframe

	window.parentDojo = undefined;
	window.restrictedParent = undefined;

	try {
		window.parentDojo = parent.dojo ? parent.dojo : undefined;
		if(parent != self && !parent.dojo) {
			window.restrictedParent = true; // IE never throws an error inside of this try-catch statement
			dojo._global_omit_module_check = true; // dojo's module check would fail for IE in that case
		}
	}catch(ex) {
		window.restrictedParent = true;	// page embedded into cross site iframe -> resticted access
	}

	if(parent != self && window.parentDojo !== undefined) {
		parent.epages._windows.push(window);
		for( var i=0,iLength=parent.epages.onIframeStart.length ; i<iLength ; i++ ) {
			parent.epages.onIframeStart[i](parent, window);
		}
		// epages NavBars are globals
		if(epages.NavBars == undefined){
			epages.NavBars = {};
		}
		epages.NavBars = parent.epages.NavBars;
	}
})();

dojo.subscribe('epages/addGlobalSymbol', function(gvn, win) {
	if (win === undefined) {
		console.warn('no target window for addGlobalSymbol');
		return;
	}
	if (win[gvn] != null){
		return;
	}

	if(window.parentDojo){
		win[gvn] = parent[gvn];
	}
});

dojo.mixin( epages, {
	onIframeStart: [],
	onUnloadFunctions: [],
	topDojo: (parent != self && window.parentDojo !== undefined) ? window.parentDojo : dojo,
	topWindow: parent,
	constants: {
		preventCache: false,
		doFlashForward: true
	},
	theme: {
		name: 'epages',
		url:  dojo.moduleUrl('dijit.themes', 'epages')
	},
	// all known windows using epages
	_windows: [ window ],
	// all global vars
	_gvs: {},
	zIndex: 10000,

	buildNode: function(attributeArray /* Array */, nodeOrTagRef /* String or DOM node */, content /* String - Optional */, containerNodeName /* String */) {
		// summary:
		//		Injects or expands a node in the current page source.
		// description:
		//		Since we're using attributes that are not valid XHTML syntax we have to cloak
		//		the instantiation of nodes with such attributes attached.
		//
		//		In the future this method could be used to increase the rendering performance.
		//		If the global configuration attribute "djConfig.parseOnLoad" is set to "false"
		//		we could take care of the parsing process in here (and therefore would save
		//		time which is now spent for the global dojo.query("[dojoType]") method).
		// attributeArray:
		//		An array with subarrays of the attributes to be attached to the node.
		// nodeOrTagRef:
		//		Can be a plain tag name > A new node with the specified tag will be created.
		//		Can be a node id as string > The specified node will be extended.
		//		Can be a node reference itself > The specified node will be extended.
		// content:
		//		The new content of the node.
		// example:
		//		epages.buildNode([
		//			["type", "text"],
		//			["dojoType", "epages.widget.NumberSpinner"],
		//			["name", "Quantity"],
		//			["class", "Quantity"],
		//			["value", "#MinOrder[float]"],
		//			["delta", "#IntervalOrder[float]"]
		//		], "input");

		if(attributeArray && attributeArray.length && nodeOrTagRef ) {

			var node;						// main node reference
			var containerNode;	// temporary parent node (never inserted to the DOM)

			if(typeof(nodeOrTagRef) === "string") {
				var nodeRef = $(nodeOrTagRef);
				if(nodeRef) {
					// an id string is passed
					node = nodeRef;
				}else {
					// a tag name is passed
					node = document.createElement(nodeOrTagRef);
					containerNode = document.createElement("div");
				}
			}else {
				// a node reference is passed
				node = nodeOrTagRef;
			}

			if(content) { // rewrites an existing node
				node.innerHTML = content;
			}

			for( var i=0,iLength=attributeArray.length ; i<iLength ; i++ ) {
				if(attributeArray[i][0] === "style") {
					node.style.cssText = attributeArray[i][1];
				}else if(attributeArray[i][0] === "name" && epages.Browser.engine === "MSIE") {
					// somehow the native attribute "name" is written uppercase in the MSIE. Hence we're attaching it separately for this browser.
					node.Name = attributeArray[i][1];
				}else {
					node.setAttribute(attributeArray[i][0], attributeArray[i][1]);
				}
			}

			if(containerNode) {
				if(!containerNodeName) {
					console.warn("error in buildNode method: no containerNodeName string given as container for creating new DOM nodes");
					return;
				}
				containerNode.appendChild(node);
				//document.write(containerNode.innerHTML);
				dojo.create('div', { 'innerHTML' : containerNode.innerHTML, 'style' : 'display:inline' }, containerNodeName, 'before');
			}
		}
	},

	flashForward: function () {
		return epages.constants.doFlashForward;
	},

	setTheme: function (/*String*/theme) {
		var body = dojo.body();
		var old = epages.theme.name;
		if (body){
			dojo.removeClass(body, epages.theme.name);
		} else {
			dojo.addOnLoad(function() {
				var body = dojo.body();
				if (body) {
					dojo.removeClass(body, epages.theme.name);
					dojo.addClass(body, theme);
				}
			});
		}
		epages.theme.name= theme;
		epages.theme.url = dojo.moduleUrl('dijit.themes', theme);
		if (body){
			dojo.addClass(body, theme);
		}
	},

	themeUrl: function (/*String*/path) {
		return epages.theme.url + '/' + path;
	},

	reload: function() {
		window.location.hash += "0";
		var url = window.location.href;
		window.location.href = url.substring(0, url.indexOf('#'));
	},

	locationHref: function(uri) {
		window.location.href = uri.substr(0,1) == '?' ? epages.vars.BaseUrl + uri : uri;
	},

	setFormAction: function(formRef, newAction) {
		formRef.action = newAction.substr(0,1) == '?' ? epages.vars.BaseUrl + newAction : newAction;
	},

	locationWebRoot: function(uri) {
		return window.location.protocol + '//' + window.location.host + uri;
	},

	Class: function() {
		return function() {
			this.initialize.apply(this, arguments);
		};
	},

	changeSampleText: function(newdata,group) {
	// this function replaces the data in samp tags (newdata) which are specified
	// by their title attributes (group)
		if(!newdata){
			newdata="";
		}
		var sampletags = document.getElementsByTagName("samp");
		for( var i=0,iLength=sampletags.length ; i<iLength ; i++ ) {
			if(sampletags[i].getAttribute("title") == group) {
				if(sampletags[i].firstChild) {
					sampletags[i].firstChild.data = newdata;
				} else {
					var mydata = document.createTextNode(newdata);
					sampletags[i].appendChild(mydata);
				}
			}
		}
	},

	toggleNodes: function(className /* class of toggled elements */, clearSpace /* true = "display" else "visibility" */, classLimiter /* element that is been scanned for className */) {
		if(typeof className == "string") {
			if(typeof classLimiter == "undefined") {classLimiter = document;}
			if(typeof classLimiter == "string") {classLimiter = document.getElementById(classLimiter);}
			var domElements = classLimiter.getElementsByTagName("*");
			for( var i=0,iLength=domElements.length ; i<iLength ; i++ ) {
				if(domElements[i].attributes && domElements[i].attributes["class"] &&
						domElements[i].attributes["class"].nodeValue.indexOf(className) > -1) {
					if(clearSpace) {
						if(domElements[i].className.match(/HideNode/)) {
								domElements[i].className = domElements[i].className.replace(/HideNode/,'ShowNode');
						}else{
							if(domElements[i].className.match(/ShowNode/)) {
								domElements[i].className = domElements[i].className.replace(/ShowNode/,'HideNode');
							}else {
								if(domElements[i].style.display == "none"){
									domElements[i].style.display = "";
								}else if(domElements[i].style.display != "none"){
									domElements[i].style.display = "none";
								}
							}
						}
						if(domElements[i].className.match(/HideElement/)) {
								domElements[i].className = domElements[i].className.replace(/HideElement/,'ShowElement');
						}
					}else{
						if(domElements[i].style.visibility == "hidden") {
							domElements[i].style.visibility = "visible";
							if(domElements[i].style.display == "none"){
								domElements[i].style.display = "";
							}
							domElements[i].className = domElements[i].className.replace(/HideNode/,'ShowNode');
							domElements[i].className = domElements[i].className.replace(/HideElement/,'ShowElement');
						}else{
							domElements[i].style.visibility = "hidden";
						}
					}
				}
			}
		}
	},

	changeDelimiter: function(DelimiterSymbol, SelectId){
			switch(DelimiterSymbol) {
					case ',' :
					document.getElementById(SelectId).options[0].selected = 'selected';
					break;
					case ';' :
					document.getElementById(SelectId).options[1].selected = 'selected';
					break;
					default :
					document.getElementById(SelectId).options[2].selected = 'selected';
					break;
			}
	},

	toggleLink: function(LinkName){
		if(document.getElementsByName(LinkName)[0].className == 'ShowLink') {
			document.getElementsByName(LinkName)[0].className = 'HideLink';
		}
		else {
			document.getElementsByName(LinkName)[0].className = 'ShowLink';
		}
	},

	/* - MBO Search (Toolbar) -------------------------------------------------------------*/
	toggleExtender: function(object){
		// toggles between the image file names of the extend button
		// object => image node
		var splittedFilename = object.src.split("/");
		var lastItemNo = splittedFilename.length-1;
		var lastItem = splittedFilename[lastItemNo];

		if(lastItem=="toolbar_ico_s_extend.png") {
			splittedFilename[lastItemNo]="toolbar_ico_s_extend_open.png";
		} else {
			splittedFilename[lastItemNo]="toolbar_ico_s_extend.png";
		}
		object.src = splittedFilename.join("/");
	},

	getDocumentWindow: function(doc) {
		return (doc.parentWindow) ? doc.parentWindow : doc.defaultView;
	},

	// returns the url for the iframe wrapper
	// this is useful for external iframes to override/set the charset if it is missing
	getIframeWrapperUrl: function(/*string*/url, /*string?*/charset) {
		var src = '?iframeUrl=' + encodeURIComponent(url);
		if (charset){
			src += '&charset=' + encodeURIComponent(charset);
		}
		return dojo.moduleUrl('epages', 'iframe_wrapper.html') + src;
	},

	require: function(/*string*/packageName,/*modul*/modulName){
		//summary:
		//improve dojo.require to load shrinksafe packages
		//description:
		//check if modul is loaded
		//load package if it is not loaded
		//if package was not loaded correct do normal dojo.require

		// EPG-17181 : just do dojo.require
		if(modulName) {
			return dojo["require"](modulName);
		}
	},

	checkUnit: function(node,unitNode){
		//summary:
		//checks if unitNode has a value if node has a value
		//in error case DialogError class is added
		if(node && unitNode){
			if(unitNode.value === '' && node.value !== ''){
				dojo.addClass(unitNode, 'DialogError');
			}
			else{
				dojo.removeClass(unitNode, 'DialogError');
			}
		}
	}

});

// set default vars if not exists
if( !epages.vars ){
	epages.vars = { Locale: {} };
}

dojo.addOnLoad(function () { epages.setTheme(epages.theme.name); });

// load workarounds
dojo["require"]("epages._workaround");

$ = dojo.byId;

dojo.addOnLoad(function() {
	if(top == self){
		epages.vars.dojoUnloadStuff = window.onbeforeunload;
		window.onbeforeunload = function () {
			var l = false;
			var d = dojo;
			// for each registered epages.onUnloadFunctions element, exec the function and determine whether at least one function returned true
			d.forEach(epages.onUnloadFunctions, function (el) { l |= el(); });

			if (l) {
				d.require('epages.io.translation');
				return epages.io.dictionary.get("LoseChanges");
			}else {
				dojo["require"]("epages.browser");
				if(epages.Browser.engine == "MSIE" && epages.Browser.version > 6) {
					document.getElementsByTagName("body")[0].className += " SuspendUserInteraction";
					setTimeout(function() {
						dojo.removeClass(document.getElementsByTagName("body")[0], "SuspendUserInteraction");
					}, 2000);
					window.onunload = function() {
						if(epages.vars.dojoUnloadStuff) {epages.vars.dojoUnloadStuff();}
					};
				}
			}
			return;
		};
	}
});

epages.parentByTagName = function( node, tagName ){
	while( node.nodeName.toLocaleLowerCase()!=tagName ){
		node = node.parentNode;
		if( node.parentNode==document.body ){
			break;
		}
	}
	return node;
};

// set console (sometimes not set in time and hence throws an error)
try{
window.console = window.console || {};
window.console.debug = window.console.debug || function(){return;};
window.console.warn = window.console.warn || function(){return;};
}
catch(e){}
