#!perl -w
use strict;
use Test::Simple tests => 3;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Object::API::XMLCompare qw ( CompareXML );
use DE_EPAGES::Installer::API::PatchXMLExportDriver;
use DE_EPAGES::Core::API::File qw (DeleteFile ExistsFile);

RunScript(Sub => sub {
    ok(CleanUp(), "CleanUp");

    my $hPatchXMLHash = {
        'PatchCartridge' => {
            'OldRelease' => 'release_6_10_4',
            'NewRelease' => 'release_6_11_0',
            'NewVersion' => '6.11.0',
            'Cartridge'  => 'DE_EPAGES::Presentation',
            'OldVersion' => '6.10.4',
        },
        'PatchDBStructure' => {
            'onPatchProcessSingleFile' => {
                '02-ProceduresAndOther' => {
                    'Patches/Patch_6_10_4/Database/Sybase/Procedures/i_FormField.sql' => {},
                },
            },
        },
        'Patch' => {
            'onPatchDeleteDependencies' => {
                'Patches/Patch_6_9_4/Database/XML/del_Dependencies.xml' => {},
            },
            'onPatchDeleteShopChildDependencies' => {
                'Patches/Patch_6_9_1/Database/XML/del_ShopChildDependencies.xml' => {},
            },
            'onPatchDeleteObjects' => {
                '04-PageTypes' => {
                    'Patches/Patch_6_10_4/Database/XML/del_PageTypes.xml' => {},
                },
            },
            'onPatchDeleteHooks' => {
                'Patches/Patch_6_10_4/Database/XML/del_HooksShop.xml' => {},
            },
            'onPatchImportDependencies' => {
                'Patches/Patch_6_10_4/Database/XML/imp_Dependencies.xml' => {},
            },
            'onPatchImportObjects' => {
                '01-Attributes' => {
                    'Patches/Patch_6_10_4/Database/XML/imp_AttributesSystem.xml' => {},
                },
            },
            'onPatchImportShopChildDependencies' => {
                'Patches/Patch_6_9_1/Database/XML/imp_ShopChildDependencies.xml' => {},
            },
        },
        'PatchCartridgeDir' => {
            'onPatchDeleteCartridgeDirectory' => {
                'Data/WebRoot' => {'CVS' => 'Deleted'},
            },
            'onPatchDeleteCartridgeFile' => {
                'Data/Public/presentation_blanklayer.html' => {'CVS' => 'Deleted'},
            },
        },
    };

    my $ExportDriver = DE_EPAGES::Installer::API::PatchXMLExportDriver->new($hPatchXMLHash);


    $ExportDriver->exportXML('patch(export).xml');

    ok(
        (
            CompareXML('patch(test).xml', 'patch(export).xml', {'printmessage'=> '1'}) and
            CompareXML('patch(export).xml','patch(test).xml', {'printmessage'=> '1'})
        ),
        "export and original xml are equal"
    );

    ok(CleanUp(), "CleanUp");

}, Debug=>1);

sub CleanUp {
    DeleteFile('patch(export).xml');
    return not ExistsFile('patch(export).xml');
}
1;