jQuery.plugin( 'ep.ui.magnifier', ['ep.core', 'jQuery.ui.widget', 'jQuery.event.special.load'], function( $, undefined ){

	$.widget('ep.ui.Magnifier', {
		// default options
		options: {
		  // source-path to image
			magnifiedPicture:	'',
			// current position of mouse in image
			mouseX		:	0,
			mouseY		:	0,
			// properties of image
			imgWidth	:	0,
			imgHeight	:	0,
			imgPosLeft:	0,
			imgPosTop	:	0,
			// zoom-factor: image to magnified image
			zoomX			:	0,
			zoomY			:	0,
			// size of magnifier in px
			magSize		:	100,
			// handle
			magDiv		: undefined,					// var for the div where the magnified image is in
			magImg		: undefined,					// var for the magnified image
			_src			: ''
		},

		_setImagePreferences: function(/* BOOLEAN */ initial) {
		// summery :

			this.element.bind('load', $.proxy( function() {
				this._src = this.element.attr('src');
				// position & dimensions of image
				this.options.imgWidth = this.element.width();
				this.options.imgHeight = this.element.height();
				var tmpOffset = this.element.offset();
				this.options.imgPosLeft = Math.round(tmpOffset.left);
				this.options.imgPosTop = Math.round(tmpOffset.top);

				if( initial ) {
					// Fires only once this event
					this.element.one('mouseover.magnifier', $.proxy(this._buildMagnifier,this) );
				} else {
					// causes when a new image is in node
					this.magImg
						.bind('load', $.proxy(function(event){

							this.magDiv.css('width', this.magImg.css('width'));
							this.magDiv.css('height', this.magImg.css('height'));

							this.options.zoomX = Math.round( ( this.magDiv.width() / this.options.imgWidth ) * 100) / 100;
							this.options.zoomY = Math.round( ( this.magDiv.height() / this.options.imgHeight ) * 100) / 100;

							if( ! $.proxy(this._checkMagnifier(event), this) ) {
								this._showMagnifier();
							}

						},this));
					this.magImg.attr('src', this.options.magnifiedPicture);
				}
			}, this));
		},

		_create: function() {
		// summery : check if a magnified images is given and go further to build the magnifier
			if( this.options.magnifiedPicture ) {
				this._setImagePreferences(true);
			}
		},

		_buildMagnifier: function() {
		// summery :
			// function which build the node for the magnifier
			// fires at first enter

			// check for valid magSize
			if( !this.magSize || this.magSize >= 0 || this.magSize > this.options.imgWidth || this.magSize > this.options.imgHeight ){
			  this.magSize = 100;
			}

			this.magDiv =	$('<div>')
				.hide()
				.attr({
					'id' : 'Magnifier'
				})
				.css({
				  'position' : 'absolute',
					'z-index' : 10000
				})
				.appendTo( 'body' );

			this.magImg = $('<img>')
				.attr({
				  'src' : this.options.magnifiedPicture,
				  'alt' : ''
				})
				// Wait until the magnified image is loaded
				.bind('load', $.proxy(function(event){
					// Round to 2 decimal places
					this.options.zoomX = Math.round( ( this.magDiv.width() / this.options.imgWidth ) * 100 ) / 100;
					this.options.zoomY = Math.round( ( this.magDiv.height() / this.options.imgHeight ) * 100 ) / 100;

					// trigger the click event for the origin image-node
					this.magDiv
						.bind('click.magnifier', $.proxy( function(){
							this.element.trigger('click.magnifier');
						}, this));

					this._showMagnifier();
				}, this))
				.appendTo(this.magDiv);
		},

		_showMagnifier: function() {
		// summery :

			if( this._src === this.element.attr('src') ) {
				// content is still the same
				$(document).bind('mousemove.magnifier', $.proxy(this._moveMagnifier,this) );
				this.magDiv.show();
			} else {
				// content of img-node has changed
			}
		},

		_hideMagnifier: function() {
		// summery :

			this.magDiv.hide();
			$(document).unbind('mousemove.magnifier');
			this.element.one('mouseover.magnifier', $.proxy(this._showMagnifier,this) );
		},

		_checkMagnifier: function(/* Object */ event) {
		// summery : checks, whether mouse point

			// get current offset of image
			var tmpOffset = this.element.offset();
			this.options.imgPosLeft = Math.round(tmpOffset.left);
			this.options.imgPosTop = Math.round(tmpOffset.top);
			// get position of mouse in picture
			this.options.mouseX = event.pageX - this.options.imgPosLeft;
			this.options.mouseY = event.pageY - this.options.imgPosTop;

			if( this.options.mouseX > 0 && this.options.mouseX < this.options.imgWidth
			 && this.options.mouseY > 0 && this.options.mouseY < this.options.imgHeight ) {
				return  true;
			} else {
				return false;
			}
		},

		_moveMagnifier: function(/* Object */ event) {
		// summery :
			if( $.proxy(this._checkMagnifier(event), this) ) {
				// Mouse is still over the picture
				// position in magnified image
				var X = Math.round( this.options.mouseX * this.options.zoomX );
				var Y = Math.round( this.options.mouseY * this.options.zoomY );

				var leftClip = X - Math.round(this.options.magSize / 2);
				var topClip = Y - Math.round(this.options.magSize / 2);
				var rightClip = X + Math.round(this.options.magSize / 2);
				var bottomClip = Y + Math.round(this.options.magSize / 2);

				var left = this.options.imgPosLeft - X + this.options.mouseX;
				var top = this.options.imgPosTop - Y + this.options.mouseY;

				var clip = 'rect(' + topClip + 'px ' + rightClip + 'px ' + bottomClip + 'px ' + leftClip + 'px)';
				var backgroundPosition = '-' + (left) + 'px -' + (top) + 'px';
				this.magDiv.css({
				  'backgroundPosition' : backgroundPosition,
					'clip' : clip,
					'left' : left + 'px',
					'top' : top + 'px'
				});
			} else {
				this._hideMagnifier();
			}
		},

		setImage: function( /* String */ newImgSource, /* String */ newMagImgSource) {
		// summery : public function, setting new picture in img-node, optional magnified picture
			if( newImgSource ) {
				this.element.attr('src', newImgSource);
				if( newMagImgSource ) {
					this.options.magnifiedPicture = newMagImgSource;
				} else {
				this.options.magnifiedPicture = '';
				}
				this._setImagePreferences(false);
			}
		}
	});

});