/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.textedit
 *
 * @revision		$Revision: 1.1.2.7 $
 */

jQuery.plugin( 'ep.ui.textedit', ['ep.core', 'ep.ajax', 'ep.ui.input', 'jQuery.ui.core'], function( $, undefined ){

	$.widget( "ep.ui.Textedit",/* my.parent.widget,*/ {
		MIN_WIDTH: 50,
		options: {
			type:				'input',												// textarea or input
			action:				null,													// save action
			objectId:			ep.config.objectId !== 0 ? ep.config.objectId : null,	// object id for save
			name:				null,													// name for save
			convertLineBreaks:	false,													// new line to br
			stripHTML:			false													// remove html tags
		},

		_create: function(){
			var o = this.options;

			this.elem = this.element.sub(ep);

			this.content = this.elem.html();

			this.elem
				.bind( 'click.uiTextedit', this.Proxy('_onclick') )
				.bind( 'mouseover.uiTextedit', this.Proxy('_onmouseover') )
				.bind( 'mouseout.uiTextedit', this.Proxy('_onmouseout') );

			this.uiInput = ep( o.type === 'textarea' ? '<textarea>' : '<input type="text">' )
				.hide()
				.insertAfter( this.elem )
				.uiInput()
				.bind( 'blur.uiTextedit', this.Proxy('_onblur') )
				.bind( 'keypress.uiTextedit', this.Proxy('_onkeypress') );

			//if we have a action we also need a name to save content to the server
			if( o.action ){
				if( o.name || name ){
					this._name = o.name || name;
				}
				else{
					this._name = this.elem.attr('name');
					if( !this._name ){
						console.warn('ep.ui.textedit: unable to save: action is defined but no name is defined');
					}
				}
			}
		},

		_onclick:function( event ){
			var content = this.content;

			this.uiInput.width( Math.max( this.elem.width(), this.MIN_WIDTH ) );
			this.elem.hide();
			this.uiInput
				.show()
				.css( 'display', this.elem.data("olddisplay") );

			if( this.options.convertLineBreaks ){
				content = content.replace(/(<br>|<br \/>)/g, '\n');
			}

			this.uiInput
				.attr( 'value', content )
				.focus()
				.select();

			event.stopPropagation();
		},

		_onblur:function(){
			this._writeContentBack();
		},

		_onkeypress: function( event ){
			if( event.keyCode === 27 ){
				this.uiInput.attr( 'value', this.content );
				this._writeContentBack();
			}
			if( this.options.type === 'input' && event.keyCode === 13 ){
				this._writeContentBack();
			}
		},

		_onmouseover: function(){
			this.elem.addClass('ep-uiTextedit-Hover');
		},

		_onmouseout: function(){
			this.elem.removeClass('ep-uiTextedit-Hover');
		},

		_writeContentBack: function(){
			var o = this.options;

			this.elem.show();
			this.uiInput.hide();
			this.content = this.uiInput.attr('value');
			if( o.stripHTML){
				this.content = ep.stripTags(this.content);
			}
			if( o.convertLineBreaks){
				this.content = this.content.replace( /(\n)/g, '<br />' );
			}
			this.elem.html(this.content);
			if( o.action && o.objectId && this._name){
				this._saveContent();
			}
		},

		_saveContent: function(){
			var o = this.options,
				jsonData = {
					'ViewAction':	'JSONViewResponse',
					'ObjectID':		o.objectId,
					'ChangeAction':	o.action
				};

			jsonData[this._name] = this.content;

			ep.ajax({
				dataType:	'json',
				data:		jsonData,
				context:	this
			});
		},

		destroy: function(){
			this.uiInput.remove();
			this.elem
				.unbind('.uiTextedit')
				.show();

			this.Inherited();
		}

	});

});
