use strict;
use Test::Simple tests => 5;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Object::API::Factory qw( ExistsObjectByPath LoadObjectByPath LoadRootObject
                                        LoadClassByAlias ExistsClassByAlias );
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );

my $ATTRIBUTE_PACKAGE = 'DE_EPAGES::Object::API::Attributes::HashAttribute';
my $ROOTPATH = '/Test';

sub Main {
    ConnectTestSite();

    # create test classes
    ok( Init(), "initialization" );

    my $TestObject = LoadObjectByPath( $ROOTPATH );
    my $Object = LoadClassByAlias('C1')->insertObject({
        Parent => $TestObject,
        Alias => 'C1O1'
    } );
    my $SollData = {
        'center' => '12345',
        'height' => '220',
        'width'  => '200',
    };

    $Object->set({'GoogleMap'=> $SollData});

    my $IsData = $Object->get('GoogleMap');
    foreach my $Key (keys %$SollData) {
        ok($IsData->{$Key} eq $SollData->{$Key}, $Key . "= $IsData->{$Key} eq $SollData->{$Key}");
    }
    ok( Cleanup(), "cleanup" );

    DisconnectSite();
}

sub Cleanup {
    if( ExistsClassByAlias( 'C1' ) ) {
        LoadClassByAlias( 'C1' )->delete;
    }
    if( ExistsObjectByPath( $ROOTPATH ) ) {
        LoadObjectByPath( $ROOTPATH )->delete;
    }
    return 1;
}

sub Init {
    Cleanup();
    my $ClassObject = LoadClassByAlias( 'Object' );
    my $Class1 = $ClassObject->insertSubClass({ Alias => 'C1' });
    $Class1->insertAttribute({ Alias => 'GoogleMap', Type => 'Hash', Package => $ATTRIBUTE_PACKAGE });

    $ClassObject->insertObject( { Alias => 'Test', Parent => LoadRootObject() } );
    return 1;
}

RunScript(Sub=>\&Main, Debug=>1);
