dojo.provide("epages.cartridges.de_epages.presentation.dragdrop");
dojo.require("epages.browser");
dojo.require("epages.html.element");
dojo.require("epages.event.sensitiveborders");

$DND = /*epages.cartridges.de_epages.presentation.Dragdrop*/function (/* string */ handlerId,/* array? */ elements, /* object?*/ screenContainer) {
	return new epages.cartridges.de_epages.presentation.Dragdrop(handlerId,elements, screenContainer);
};

epages.cartridges.de_epages.presentation.Dragdrop = function(/* string */ handlerId,/* array? */ elements, /* object?*/ screenContainer) {
	this.elements = [];

	this.screenContainer=(screenContainer) ? screenContainer : (epages.Browser.engine == "WebKit" ? document.documentElement : dojo.body());

	if(elements !== undefined){
		for(var el in elements){
			this.addElement(elements[el]);
		}
	}

	this.handlerId=handlerId;
	this.isDragging = false;
	this._appendBodyEvents();
};

epages.cartridges.de_epages.presentation.Dragdrop.prototype = {
	dragObject : undefined,
	isDragging : undefined,
	handlerId  : undefined,
	elements   : undefined,
	screenContainer : undefined,

	addElement: function(el) {
		if(el.clickNode) {  // is object
			var clickEl = el.clickNode;
			var moveEl  = el.clickNode;
			if(el.moveNode){
				moveEl = el.moveNode;
			}else{
				el.moveNode = moveEl;
			}
			this.elements.push(el);
		} else {            // is DOM node
			var clickEl = el;
			var moveEl  = el;
			// transform to object
			this.elements.push({
				clickNode: el,
				moveNode: el
			});
		}

		//get drag drop element
		dojo.connect(clickEl,'onmousedown', this, '_startDragging');
		dojo.connect(moveEl, 'onmousedown', this, '_setMoveTarget');

		clickEl.style.cursor="move";
		moveEl.style.position="relative";
	},

	_appendBodyEvents: function() {
		dojo.connect(document, 'onmousemove', this, '_onmousemove');
		dojo.connect(document, 'onmouseup', this, '_onmouseup');
	},

	_getCurrentElement: function(node) {
		for(el in this.elements) {
			if(node===this.elements[el].moveNode) {
				return this.elements[el];
			}
		}
		return false;
	},

	_getScreenContainerOffset: function() {
		if(this.screenContainer.nodeName!="BODY"){
			var pos=$E(this.screenContainer).getAbsolutePosition();
		} else {
			var pos = {};
			pos.y=0;
			pos.x=0;
		}
		return pos;
	},

	_getScrollOffset: function() {
		var pos = {};
		var relativeScrollParent = (epages.Browser.engine == "MSIE" && this.screenContainer.tagName == "BODY") ? this.screenContainer.parentNode : this.screenContainer;
		pos.y = relativeScrollParent.scrollTop;
		pos.x = relativeScrollParent.scrollLeft;
		return pos;
	},

	_setNodeSize: function(node) {
		var nodeWidth=node.clientWidth;
		if(nodeWidth == 0){
			nodeWidth=node.offsetWidth;
		}
		node.style.width = nodeWidth+"px";
		if (node.outerHeight) {
			node.style.height = node.outerHeight+"px";
		} else {
			node.style.height = node.clientHeight+"px";
		}
	},

	_clearNodeSize: function(node) {
		node.style.width= "";
		node.style.height= "";
	},

	_getPositionOnScreenContainer: function(evt) {
		var scrollOffset=this._getScrollOffset();
		if(epages.Browser.engine=="MSIE") {
			var x= evt.clientX-this.dragObject.offsetX+scrollOffset.x;
			var y= evt.clientY-this.dragObject.offsetY+scrollOffset.y;
		} else {
			var x= evt.pageX-this.dragObject.offsetX+scrollOffset.x;
			var y= evt.pageY-this.dragObject.offsetY+scrollOffset.y;
		}
		return { x:x, y:y };
	},

	_onmousemove: function(evt) {
		if(this.dragObject && this.isDragging) {
			dojo.addClass(this.dragObject.domElement,"IsDragging");

			dojo.addClass(document.getElementsByTagName("body")[0],"IsDropArea");

			// get coordinates
			var screenOffset = this._getScreenContainerOffset();
			var pos=this._getPositionOnScreenContainer(evt);

			// set position
			this._setPosition(pos.x-screenOffset.x,pos.y-screenOffset.y);
			this.dragObject.domElement.style.position="absolute";
			this.dragObject.domElement.style.zIndex="100000";

			var currentElement=this._getCurrentElement(this.dragObject.domElement);
			// publish event
			dojo.publish('dragdrop'+this.handlerId+'/move', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: currentElement
			}]);

		}
	},

	_onmouseup: function(evt) {
		if(this.isDragging) {

			epages.event.sensitiveBorders.disable();

			// get coordinates
			var screenOffset = this._getScreenContainerOffset();
			var pos=this._getPositionOnScreenContainer(evt);

			var currentElement=this._getCurrentElement(this.dragObject.domElement);

			// publish event
			dojo.publish('dragdrop'+this.handlerId+'/drop', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: currentElement
			}]);

			// execute elements onDrop function
			if(currentElement && currentElement.onDrop){
				currentElement.onDrop();
			}

			// reset
			this._clearNodeSize(this.dragObject.domElement);

			dojo.removeClass(this.dragObject.domElement,"IsDragging");

			dojo.removeClass(document.getElementsByTagName("body")[0],"IsDropArea");

			this.isDragging = false;
			this.dragObject.domElement.style.position="relative";
			this.dragObject.domElement.style.left="";
			this.dragObject.domElement.style.top="";
			this.dragObject.domElement.style.zIndex="";
			this.dragObject.domElement.style.zoom="1";
			this.dragObject = undefined;

			document.body.onselectstart = function(){};
			document.body.style.MozUserSelect = "";
		}
	},

	_startDragging: function(evt) {
		document.body.onselectstart = function() {
			return false;
		};
		document.body.style.MozUserSelect = "none";
		epages.event.sensitiveBorders.enable();
		this.isDragging = true;
		dojo.publish('dragdrop'+this.handlerId+'/beforeStart',[{
			event: evt
		}]);
	},

	_setMoveTarget: function(evt) {
	// _startDragging() should always be executed before _setMoveTarget()
		var moveNode = evt.target;
		var dragNode = evt.currentTarget;
		var distance = {};
		if(dragNode !== moveNode) {
			distance = $E(moveNode).getPositionToParent(dragNode);
		} else {
			distance.x = 0;
			distance.y = 0;
		}

		this.dragObject = {
			domElement: dragNode,
			offsetX   : (epages.Browser.engine.match("MSIE")) ? evt.offsetX: evt.layerX + distance.x,
			offsetY   : (epages.Browser.engine.match("MSIE")) ? evt.offsetY: evt.layerY  + distance.y
		};
		// debug offset coordinates & domElement
		// console.debug(this.dragObject.offsetX + " ; "+ this.dragObject.offsetY + " / "+ this.dragObject.domElement.style.position);

		if(this.isDragging) {
			var currentElement=this._getCurrentElement(this.dragObject.domElement);
			if(currentElement.forceSize){
				this._setNodeSize(this.dragObject.domElement);
			}

			var pos=this._getPositionOnScreenContainer(evt);

			dojo.publish('dragdrop'+this.handlerId+'/start', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: this.dragObject
			}]);
		}
	},

	_setPosition: function(x,y) {
		this.dragObject.domElement.style.left = x+'px';
		this.dragObject.domElement.style.top = y+'px';
	}

};
