dojo.provide('epages.cartridges.de_epages.presentation.widget.HtmlInlineEditor');
dojo.require('epages.cartridges.de_epages.presentation.widget.InlineEditor');
dojo.require("epages.html");
dojo.require("epages.io.json");
dojo.require("epages.cartridges.de_epages.presentation.widget.EditorPlaceholder");

dojo.publish('epages/addGlobalSymbol', ['tinymce', window]);
dojo.publish('epages/addGlobalSymbol', ['tinyMCE', window]);

// inline editor for html (formatted) text, uses TinyMCE Rich-Text-Editor
dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.HtmlInlineEditor",
	epages.cartridges.de_epages.presentation.widget.InlineEditor,
	{
		getAction 	: 'JSONGet',
		postCreate: function() {
			this.inherited('postCreate', arguments);
			epages.topDojo.subscribe('tinymce_windowmanager_open/changeContent',this,'onTinyMCEChangeContent');
			epages.topDojo.subscribe("uimessage/startBusy",this,"hideOnSave");
		},

		show: function() {
			// needed for rendering of editors
			tinymce.DOM.doc = window.document;

			// TinyMCE WYSIWYG Editor
			if (this.displayNode.innerHTML == this._placeHolderText){
				this.displayNode.innerHTML = '';
			}
			if (this.object == null) {
				var doc = this.domNode.ownerDocument;
				var settings = tinyMCE.settings;

				settings.content_element = this.displayNode;
				this.value = (this.getRemoteValue() || "");
				settings.content_element.innerHTML = this.value;

				this.replaceGadgets(settings.content_element);

				settings.body_class = "ShowVisualAid  Inline ";
				if(this.navbar != ""){
					settings.body_class +="mceShow"+ this.navbar;
				}

				this.object = new tinymce.Editor("InlineEditor_" + this.id, settings);

				this.object.onInit.add(dojo.hitch(this, function() {
					// add undo functionality
					if (this.undoObject) {

						// force refresh of content, to get the effects of tinymce cleanup functions
						var content = this.object.getContent();
						this.object.setContent(content);
						this.contentNode.value = content;

						if (this.undoObject){
							this.undoObject.setDefaultValue(this.contentNode);
						}
						this.object.undoManager = new epages.html.TinymceUndoManagerAdapter(
							this.undoObject,
							this.contentNode,
							dojo.hitch(this, 'onChange')
						);

						this.object.onEvent.add(dojo.hitch(this, function() {
							this.undoObject.checkTyping(Boolean(this.object.undoManager.typing));
						}));
					}
				}));

				this.object.render();

				// add css class to iframe
				var iframe = $('InlineEditor_' + this.id + '_ifr', doc);
				$E(iframe).addClassName('EditorIframe');
				iframe.allowTransparency="true";

				this.isInited = true;
			} else {
				this.object.show();
			}
			this.displayNode.style.display = 'none';
			this.inherited('show', arguments);
		},

		hide: function(evt) {
			if (!this.isInited){
				return;
			}
			this.object.hide();
			this.contentNode.style.display = 'none';
			this.contentNode.value = this.object.getContent().replace(/\s*\<br\s*\/?\>\s*$/, "");
			this.displayNode.innerHTML = this.contentNode.value;
			this.displayNode.style.display = '';
			if(this.undoObject.isTyping == true){
				this.undoObject.checkTyping(false);
			}
			this.inherited('hide', arguments);
		},

		// gets called, when data is changed (from outside)
		onChangeContentNode: function() {
			var value = this.contentNode.value;

			// put value to DOM, replaceGadgets only work with DOM, not with strings
			var tmp = dojo.query("div[name='temp']")[0]
			if( !tmp ) {
				tmp = dojo.create("div", {"name":"temp"});
			}
			tmp.innerHTML = value;
			this.replaceGadgets(tmp);
			value = tmp.innerHTML;

			// update editor
			if(this.object){
				this.object.setContent(value);
			}
			// update displayed content
			this.displayNode.innerHTML = value;
		},

		onTinyMCEChangeContent: function(editorId){
			if(editorId == this.contentNode.id){
				this.onChange();
			}
		},

		getRemoteValue: function() {
			var json = new epages.io.Json();
			var result = json.loadSync(
				'?ObjectID=' + this.objectId + '&ViewAction=' + this.getAction,
				{
					'Attributes': this.attribute,
					'LanguageID': this.languageId
				}
			);
			return result.data[this.attribute];
		},

		hideOnSave: function(id){
			if(id == 'Undobuttons'){
				this.hide();
			}
		},

		replaceGadgets: function (domNode) {
			var gadgets = epages.html.getElementsByClassName('epItemContent', domNode);
			for( var i=0,l=gadgets.length ; i<l ; i++ ) {
				var g = gadgets[i];
				var epInfo = g.getAttribute('ep_info');
				if(!epInfo){
					var epRegEx = new RegExp ("ep_info:(.*)","mig");
					var regExResult = epRegEx.exec(g.className);
					if(regExResult){
						epInfo = regExResult[1];
					}
				}
				if(epInfo){
					new epages.cartridges.de_epages.presentation.widget.EditorPlaceholder({ep_info: epInfo},g);
				}
			}
		}

	}
);
