/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.product.ui.appointmentpicker
 *
 * @revision		$Revision: 1.1.6.10 $
 */

jQuery.plugin( 'de_epages.product.ui.appointmentpicker', ['de_epages.core', 'ep.ui.datepicker', 'ep.alert', 'ep.ajax'], function( $, undefined ){

/*
 * @dictionary		ep.dict
 *
 * @translation		{CALENDAR_DATA_NOT_LOAD}
 */

	$.widget('de_epages.product.ui.Appointmentpicker',ep.ui.Datepicker,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	tooltipOffset:		[0,-7],
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Datepicker
		//	type:				'date',
		//	format:				'l',
		//	showOn:				'both',
		//	duration:			'normal',
		//	show:				'fadeIn',
		//	hide:				'fadeOut',
		//	weekDaysAvailable:	[0,0,1,1,1,1,1],
		//	numberOfMonths:		1,
		//	showOtherMonth:		true,
		//	selectOtherMonth:	false,
		//	changeMonth:		true,
		//	changeYear:			true,
		//	positionAdjust:		[-1,2],
		//	region:				ep.config.region,
		//	time:				true,
		//	timeStep:			15,

	//	ep.ui.DatepickerApp
			time:				true,
			appointment: {							// hash to perform appointment available
				id:					0,
				quantityMin:		1,
				quantityRequested:	1,
				quantityAvailable:	1,
				minutesRequested:	60
			}
		},

		_create: function(){
			this.Inherited();
			this._appointmentSort = {};
			this._appointmentStack = {};

			this._loadAppointment( this._date.clone().addDate(-7), true );
		},

		_createTimeSelect: function(){
			this.timeSelect = ep('<select>')
				.attr({
					'class': 'epWidth100'
				})
				.appendTo( this.timeBar )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-time')
				.bind( 'changeValue.uiAppointmentpicker', this.Proxy('_changeTimeVal') );

			this._setTimeVal();

			this.stack.push( this.timeSelect[0]	);
		},

		_createCalendars: function(){
			this.Inherited(arguments);
			this._createTimeSelectData();
		},

		_calendarData: function(){
			var self			= this,
				o				= this.options,
				opt				= o.appointment,
				calendarsData	= this.Inherited(arguments),
				appData			= $.scope( opt.minutesRequested+'', this._appointmentStack ),
				load			= false;

			$.each( calendarsData, function( i, calendarData ){
				$.each( calendarData.days, function( j, day ){
					if( this.clickable ){
						var date = day.date,
							dateString = date.getFormat('S'),
							dayObj = appData[ dateString ];

						if( !dayObj && !load ){
							appData	= self._loadAppointment( date.clone() );
							dayObj = appData[ dateString ];
							load = true;
						}

						this.clickable = !!(dayObj && dayObj.IsAvailable);
					}
				});
			});

			return calendarsData;
		},

		_createTimeSelectData: function(){
			var self			= this,
				opt				= this.options.appointment,
				dayData			= $.scope(  opt.minutesRequested+'', this._appointmentStack )[ this._dateSelected.clone().getFormat('S') ];

			this.timeSelect
				.html('');

			if( dayData ){
				var region				= {region: this.options.region};

				$.each( dayData.DayList, function( i, data ){
					if( (opt.quantityAvailable-data[1]) >= opt.quantityRequested ){
						var date = new ep.Date(data[0]);
						$('<option>')
							.attr( 'value', date.setFullYear(0,0,0).getTime() )
							.text( date.getFormat( 't', region ) )
							.appendTo( self.timeSelect );
					}
				});
			}

			this._setTimeVal();
		},

		_setTimeVal: function(){
			var self			= this,
				selectedTime	= this._timeSelected.getTime()+'',
				selectedNode,
				selectedIndex;

			$.each( this.timeSelect[0].options, function( i, node ){
				if( node.value === selectedTime ){
					node.selected = true;
					selectedNode = node;
					selectedIndex = i;
					return false;
				}
			});

			if( !selectedNode && this.timeSelect[0].options.length ){
				selectedNode = this.timeSelect[0].options[0];
				selectedIndex = 0;
				selectedNode.selected = true;
				selectedTime = selectedNode.value;
			}

			this._timeSelected = new ep.Date(selectedTime);

			if( !this.elem.is(':focused') ){
				this._setElemVal(true);
			}
		},

		_getTimeVal: function(){
			var opt = this.timeSelect[0].selectedIndex >= 0 ?
						this.timeSelect[0].options[ this.timeSelect[0].selectedIndex ] :
						null,
				date = opt ? new ep.Date(opt.value) : new ep.Date();
			return date.setFullYear(0,0,0);
		},
		// attention the date object will be modified, be sure to use an cloned date object
		_loadAppointment: function( date, preload ){
			var self		= this,
				o			= this.options,
				opt			= o.appointment,
				startDate	= date,
				endDate		= startDate.clone().addMonth( o.numberOfMonths + 2 ),
				ret;

			ep.ajax({
				data: {
					'ViewAction':		'JSON-AppointmentCalendar',
					'ObjectID':			opt.id,
					'StartDate':		startDate.getFormat('S'),
					'EndDate':			endDate.getFormat('S'),
					'RequestedMinutes':	opt.minutesRequested,
					'Available':		opt.quantityAvailable,
					'UseTimestamps':	1
				},
				async: !!preload,
				dataType: 'json',
				context: this,
				success: function( data ){
					ret = self._fixUnavailableDays( startDate, endDate, data );
				},
				error: function( xhr, status, error ){
					if( !preload ){
						this.hide();
						ep.alert({
							type:		'error',
							content:	self.dict.translate('CALENDAR_DATA_NOT_LOAD')
						});
					}
				}
			});

			return ret;
		},

		updateAppointment: function( options ){
			$.extend( this.options.appointment, options );
			// preload data
			this._loadAppointment( this._date.clone().addDate(-7), true );
		},

		_fixUnavailableDays: function( start, end, data ){
			var self =		this,
				minReq =	this.options.appointment.minutesRequested,
				sort =		this._appointmentSort[ minReq ] = this._appointmentSort[ minReq ] || [],
				stack =		this._appointmentStack[ minReq ] = this._appointmentStack[ minReq ] || {},
				count =		start.clone(),
				endTime =	end.getTime();

			while( count.getTime() <= endTime ){
				var dateString = count.getFormat('S');

				sort.push( dateString );

				stack[ dateString ] = data[ dateString ] || {IsAvailable:0,DayList:[]};

				count.addDate(1);
			}

			sort.sort();

			$.each( sort, function( i, dateString ){
				if( stack[dateString].IsAvailable ){
					var minDate =		new ep.Date( stack[dateString].DayList[0][0] )
						minTimstamp =	self.options.min = minDate.getTime(),
						curDateString =	self._dateSelected.getFormat('S'),
						curDayObj =		stack[ curDateString ];

					if( !curDayObj || !curDayObj.IsAvailable || new Date(curDayObj.DayList[0][0]).getTime() <= minTimstamp ){
						self._dateSelected = minDate.clone().setHours(0,0,0,0);
						self._timeSelected = minDate.clone().setFullYear(0,0,0);
					}

					return false;
				}
			});

			return stack;
		}
	});
});
