use strict;
use Test::More tests => 20;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath ExistsObjectByPath LoadRootObject);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);



my $ROOTPATH = '/Test';
local $ENV{'EPAGES_TESTSITE'} = 'Store' unless defined $ENV{'EPAGES_TESTSITE'};

sub Main {
    ConnectTestSite();
    ok( Init(), 'initialization' );

    my $System = LoadRootObject();
    my $Shop = LoadObjectByPath('/Test/TestShop/');
    ok( $Shop->alias eq 'TestShop', "Shop loaded" );

    my $TaxMatrix = $Shop->get('TaxMatrix');
    ok ($TaxMatrix->id != $System->get('TaxMatrix')->id, 'TaxMatrix is not System TaxMatrix');

    my $TaxArea = $TaxMatrix->insertChild('TaxArea',{'Alias'=>'Helgoland'});
    my $TaxAreaGermany = $TaxMatrix->child('Germany');

    my $SystemLocaleID = $System->get('LocaleID');
    my $SiteLocale = $System->siteLocale( $SystemLocaleID );

    my $CountryID = $SiteLocale->get('Country')->{'CountryID'};
    $TaxAreaGermany->addCountry($CountryID);

    $TaxArea->addCountry($CountryID, '12345', '22222');
    $TaxArea->addCountry($CountryID, 'A2345', 'B2222');

    ok ($TaxArea->existsCountry($CountryID, '12345', '22222'), 'exists zipcoderange');
    ok (!$TaxArea->existsCountry($CountryID, '12344', '11111'), 'not exists zipcoderange');

    ok (!$TaxArea->existsCountry($CountryID, '07741', '07741'), 'not exists zipcoderange 07741-07741');
    $TaxArea->addCountry($CountryID, '07741', '07741');
    ok (!$TaxArea->existsCountry($CountryID, '07743', '07743'), 'not exists zipcoderange 07743-07743');
    $TaxArea->addCountry($CountryID, '07740', '07781');
    ok ($TaxArea->existsCountry($CountryID, '07742', '07780'), 'exists zipcoderange 07742-07780');
    ok ($TaxArea->existsCountry($CountryID, '07745', '07745'), 'exists zipcoderange 07745-07745');
    ok ($TaxArea->existsCountry($CountryID, '07739', '07782'), 'exists zipcoderange 07739-07782');

    ok ($TaxArea->existsCountry($CountryID, '12345'), 'exists zipcode 12345');
    ok ($TaxArea->existsCountry($CountryID, '14345'), 'exists zipcode 14345');
    ok ($TaxArea->existsCountry($CountryID, 'A4345'), 'exists zipcode A4345');
    ok (!$TaxArea->existsCountry($CountryID, 10345), 'not exists zipcode 10345');
    ok (!$TaxArea->existsCountry($CountryID, '30345'), 'not exists zipcode 30345');
    ok (!$TaxArea->existsCountry($CountryID, 'B3345'), 'not exists zipcode B3345');

    $TaxArea->removeCountry($CountryID, 'A2345', 'B2222');
    ok (!$TaxArea->existsCountry($CountryID, 'A2345', 'B2222'), 'removed zipcoderange');

    ok($TaxMatrix->taxAreaByCountry($CountryID, '12355')->alias eq 'Helgoland', 'taxarea is Helgoland');
    is($TaxMatrix->taxAreaByCountry($CountryID, '72355')->alias, 'Germany', 'taxarea is Germany');

    ok( Cleanup(), 'cleanup');
    DisconnectSite();
}

sub Cleanup {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

sub Init {
    return 1 if LoadRootObject()->existsChild('Test') && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild('Object', {'Alias'=>'Test'});
    ImportObjects('importTax.xml', $ROOTPATH);
    return 1;
}

RunScript(Sub=>\&Main, Debug=>1);
