use strict;

BasketOrderTest->runScript;

package BasketOrderTest;
use base 'DE_EPAGES::Test::API::StoreUnitTest';
use strict;

use constant NUM_TESTS => 168;
use Test::More tests => NUM_TESTS;
use DE_EPAGES::Core::API::Object::NumberFormat;
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath ExistsObjectByPath LoadRootObject ExistsClassByAlias );
use DE_EPAGES::Object::API::Language;
use DE_EPAGES::Object::API::Table::Country qw (GetInfoCountry);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);
use DE_EPAGES::Order::API::Order qw (Basket2Order);
use DE_EPAGES::Product::API::Basket qw ( AddProducts );
use DE_EPAGES::Shop::API::Constants qw (TAX_MODEL_NET TAX_MODEL_GROSS);
use DE_EPAGES::Test::API::StoreUnitTest;

## no critic qw( ProhibitMagicNumbers )

sub _rootPath {
    return '/Test';
}

sub test {
    my $self = shift;

    SKIP: {
        skip 'class CustomerOrder does not exist', NUM_TESTS unless ExistsClassByAlias('CustomerOrder');

        my $Formatter = DE_EPAGES::Core::API::Object::NumberFormat->new(
                decimal_point  => ',',
                thousands_sep  => '.',
                decimal_fill   => 1,
                decimal_digits => 2,
        );

        my @Products = getProducts();
        my @Users = getUsers();
        foreach my $User (@Users) {
            $DE_EPAGES::Object::API::Language::LANGUAGEID = $User->get('LanguageID');
            foreach my $BillingAddress (@{$User->get('Addresses')}) {
                note sprintf "User: %s (%s), CountryID: %s\n", $User->get('Alias'), $User->id, $BillingAddress->get('CountryID');

                $User->set({'BillingAddress' => $BillingAddress});
                $User->set({'ShippingAddress' => $BillingAddress});
                my $aBaskets = AddProducts( $User, {}, \@Products );
                my $Basket = $aBaskets->[0];
                ok($Basket->id, 'basket created');


                my $Customer = $Basket->get('Customer');
                my $WithoutTax = 0;
                my $CountryID = $BillingAddress->get('CountryID');
                my $ShopCountryID = $Basket->getSite()->get('Address')->get('CountryID');
                if ($Customer->get('TaxModel') == TAX_MODEL_NET &&
                   $CountryID != $ShopCountryID && GetInfoCountry($CountryID)->{'IsEU'} &&
                   GetInfoCountry($ShopCountryID)->{'IsEU'} && defined $Customer->get('BillingAddress')->get('VATID')) {
                    $WithoutTax = 1;
                } elsif (!GetInfoCountry($CountryID)->{'IsEU'}) {
                    $WithoutTax = 1;
                }

                my $BasketLineItemContainer = $Basket->get('LineItemContainer');
                my $aBasketLineItems = $BasketLineItemContainer->get('LineItems');
                is (scalar (@$aBasketLineItems), 5, 'add products to basket');

                my $StockCheckAlias = 'MyRedNose';
                my $StockCheckProduct = LoadObjectByPath('/Test/TestShop/Products/'.$StockCheckAlias);
                $StockCheckProduct->set({'StockLevel'=>100});
                my $StockLevelBefore = $StockCheckProduct->get('StockLevel');
                my $StockCheckQuantity = 0;

                my $totalprice = 0;
                my $TaxModel = $Basket->container->get('TaxModel');
                my $ShippingPaymentPrice = $TaxModel == TAX_MODEL_GROSS ? 40 : 2*16.81;
                for my $LineItem (@$aBasketLineItems){
                    if ($LineItem->get('Name') eq 'MyPetrol'){
                        $totalprice += $Formatter->round(($LineItem->get('BasePrice') * $LineItem->get('Quantity')) - ($LineItem->get('BasePrice') * $LineItem->get('Quantity') * 0.1));
                    } else {
                        $totalprice += $Formatter->round($LineItem->get('BasePrice') * $LineItem->get('Quantity'));
                    }
                    if ($LineItem->get('Name') eq $StockCheckAlias){
                        $StockCheckQuantity = $LineItem->get('Quantity');
                    }
                }

                my $tmp1 = $Formatter->round(getPrice($totalprice + $ShippingPaymentPrice, $WithoutTax, $TaxModel));
                my $tmp2 = $Formatter->round($BasketLineItemContainer->get('GrandTotal'));
                is ($tmp2, $tmp1, 'correct total price');

                #Coupons
                my $CouponCampaign = LoadObjectByPath('/Test/TestShop/CouponCampaigns/123');
                my $aCodes = $CouponCampaign->generateNewCouponCodes( 1 );
                is (scalar (@$aCodes), 1, 'couponcodes generated');

                my $aCouponCodes = $CouponCampaign->get('CouponCodes');
                my %CouponInfo = ('CouponCode' => $aCodes->[0]);
                $aCouponCodes->[0]->addToContainer( $Basket->container, \%CouponInfo );

                $BasketLineItemContainer->recalculate;

                my $CouponValue = $Formatter->round($totalprice*0.05);
                my $PriceWithCoupon = $Formatter->round(getPrice($totalprice+$ShippingPaymentPrice-$CouponValue, $WithoutTax, $TaxModel) );
                is ($BasketLineItemContainer->get('GrandTotal'), $PriceWithCoupon, 'correct total price after add coupon');

                #Basket to Order
                $Basket->set({ 'BillingAddress', $User->get('BillingAddress')});
                my $Order = Basket2Order($Basket, { SendConfirmationMail => 0 });
                ok ($Order->id, 'basket to order');

                my $StockLevelAfter = $StockCheckProduct->get('StockLevel');
                ok ( $StockLevelAfter == $StockLevelBefore - $StockCheckQuantity,
                     "stock level reduced from $StockLevelBefore to $StockLevelAfter" );

                #change quantity
                my $LineItemContainer = $Order->get('LineItemContainer');
                my $aLineItems = $LineItemContainer->get('LineItems');
                $totalprice = 0;
                foreach my $LineItem (@$aLineItems){
                    $LineItem->set({'Quantity' => '2'});
                    if ($LineItem->get('Name') eq 'MyPetrol'){
                        $totalprice += $Formatter->round(($LineItem->get('BasePrice') * 2 - $LineItem->get('Discount')));
                    } else {
                        $totalprice += $Formatter->round(($LineItem->get('BasePrice') * 2));
                    }
                }

                is ($BasketLineItemContainer->get('GrandTotal'), $PriceWithCoupon, 'total price has not changed before "recalculate"');

                $LineItemContainer->recalculate;

                $tmp1 = $Formatter->round(getPrice($totalprice+$ShippingPaymentPrice - $CouponValue, $WithoutTax, $TaxModel));
                $tmp2 = $Formatter->round($BasketLineItemContainer->get('GrandTotal'));
                is ($tmp2, $tmp1, 'total price has changed after "recalculate"');

                $aLineItems = $LineItemContainer->get('LineItems');
                foreach my $LineItem (@$aLineItems){
                    is ($LineItem->get('BasePrice')*2-$LineItem->get('Discount'),
                        $LineItem->get('LineItemPrice'),
                        'price recalculated for '.$LineItem->get('Name'));
                }
            }
        }
    }
}

sub getUsers {
    my @Users;
    my $User = LoadObjectByPath('/Test/TestShop/Users/TestUser1');
    push @Users, $User;
    $User = LoadObjectByPath('/Test/TestShop/Users/TestUser2');
    push @Users, $User;
    $User = LoadObjectByPath('/Test/TestShop/Users/TestUser3');
    push @Users, $User;
    $User = LoadObjectByPath('/Test/TestShop/Users/TestUser4');
    push @Users, $User;
    return @Users;
}

sub getProducts {
    my @Products;
    my $Product = LoadObjectByPath('/Test/TestShop/Products/MyPetrol');
    push @Products, { Product => $Product, Quantity => 3 };
    $Product = LoadObjectByPath('/Test/TestShop/Products/MyRedNose');
    push @Products, { Product => $Product, Quantity => 10 };
    $Product = LoadObjectByPath('/Test/TestShop/Products/MyYellowNose');
    push @Products, { Product => $Product, Quantity => 4};
    $Product = LoadObjectByPath('/Test/TestShop/Products/Shirt/SubProducts/Black');
    push @Products, { Product => $Product, Quantity => 10};
    $Product = LoadObjectByPath('/Test/TestShop/Products/Bundle');
    push @Products, { Product => $Product, Quantity => 1};
    return @Products;
}

sub getPrice {
    my ($Price, $WithoutTax, $TaxModel) = @_;
    if ($TaxModel) {
        return $Price / 1.19 if $WithoutTax;
    } else {
        return $Price * 1.19 unless $WithoutTax;
    }
    return $Price;
}

sub cleanup {
    my $self = shift;

    LoadObjectByPath($self->_rootPath)->delete if ExistsObjectByPath($self->_rootPath);
    return;
}

sub init {
    my $self = shift;

    $self->SUPER::init;

    if( ExistsClassByAlias('CustomerOrder') ) {
        LoadRootObject()->insertChild('Object', {'Alias'=>'Test'});
        ImportObjects('BasketOrder.xml', $self->_rootPath);
    }
    return;
}
