use strict;
use Test::More tests => 1;
use XML::SemanticDiff;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::XML::API::BaseExportDriver;

RunScript( Sub => sub {
    my $XML = '';
    my $Writer = XML::SAX::Writer->new({
        Writer => 'DE_EPAGES::XML::API::SAXWriter',
        Output => \$XML,
    });
    my $Filter = XML::Filter::DataIndenter->new( 'Handler' => $Writer );
    my $Driver = DE_EPAGES::XML::API::BaseExportDriver->new( Handler => $Filter );

    $Driver->writeDocument( sub {
        $Driver->writeElement('Company', { Name => 'ePages' }, sub {
            $Driver->writeElement('Office', { Country => 'Germany', City => 'Jena' }, 'Development Crew');
            $Driver->writeElement('Office', { Country => 'Germany', City => 'Hamburg' }, 'Water Head');
        });
    });

    my $expectedXML = <<'END_XML';
<?xml version='1.0' encoding='utf-8'?>
<Company Name='ePages'>
  <Office Country='Germany' City='Jena'>Development Crew</Office>
  <Office Country='Germany' City='Hamburg'>Water Head</Office>
</Company>
END_XML

    my $diff = XML::SemanticDiff->new(keeplinenums => 1);
    my @Changes = ($diff->compare($XML, $expectedXML));
    ok( 0 == scalar @Changes, 'No changes' );
    foreach my $change ( @Changes ) {
        print "# $change->{message} (between lines $change->{startline} and $change->{endline})\n";
    }
});
