use strict;
use Test::More tests => 11;
use DE_EPAGES::XML::API::DateTimeFormatXML;
use DE_EPAGES::Core::API::PerlTools qw (GetLocalTimeZone);

# the test cases are designed for timezone Europe/Berlin
cmp_ok( GetLocalTimeZone(), 'eq', 'Europe/Berlin', "server timezone=Europe/Berlin");

my $Parser = new DE_EPAGES::XML::API::DateTimeFormatXML;

# all time values are converted to the local timezone
my @Data = (
    ['1971-12-26T02:03:45',       '1971-12-26T02:03:45+01:00', 'local'],
    ['1971-12-26T02:03:45Z',      '1971-12-26T03:03:45+01:00', 'Greenwich Z'],
    ['1971-12-26T02:03:45GMT',    '1971-12-26T03:03:45+01:00', 'Greenwich GMT'],
    ['1971-12-26T01:03:45+00:00', '1971-12-26T02:03:45+01:00', 'Greenwich +00:00'],
    ['1971-12-26T02:03:45+01:00', '1971-12-26T02:03:45+01:00', '+01:00'],
    ['1971-12-25T17:03:45-08:00', '1971-12-26T02:03:45+01:00', '-08:00'],
);

foreach my $aData (@Data) {
    my ($Original, $Expected, $Comment) = @$aData;

    my $dt = $Parser->parse_datetime( $Original );
    my $Result = $Parser->format_datetime( $dt );

    cmp_ok( $Result, 'eq', $Expected, $Comment )
}

my $dt = $Parser->parse_datetime( '1971-12-26T02:03:45' );
cmp_ok( $dt->time_zone_long_name, 'eq', 'floating', "parse floating" );

$dt = $Parser->parse_datetime( '1971-12-26T02:03:45-08:00' );
cmp_ok( $dt->time_zone_long_name, 'eq', 'Europe/Berlin', "timezone converted server timezone" );

$dt = DateTime->new( year => 1911, month => 1, day => 1, hour => 10, minute => 0, time_zone => 'Europe/Helsinki' );
is( $Parser->format_datetime($dt), '1911-01-01T10:00:00+01:39', 'Helsinki 1911' );

$dt = DateTime->new( year => 1700, month => 1, day => 1, hour => 10, minute => 0, time_zone => 'Europe/Berlin' );
is( $Parser->format_datetime($dt), '1700-01-01T10:00:00+00:53', 'Berlin 1700' );
