#-*- Makefile -*-

require DE_EPAGES::Core::API::Makefile;
__DATA__

!include host-$(HOSTNAME).mk

PATCH_TAG	= patch_6_11_3
PATCH_VERSION	= 6.11.3
PATCH_LEVEL	= 3
DE_EPAGES_DIR	= $(EPAGES_CARTRIDGES)\DE_EPAGES
DATA_DIR	= $(EPAGES_SHARED)\var-$(PATCH_TAG)
LOG_DIR		= $(DATA_DIR)\logs\$(HOSTNAME)
TGT		= $(DATA_DIR)\tgt\$(HOSTNAME)
BACKUP_DIR	= $(DATA_DIR)\backup\$(HOSTNAME)
BACKUP_DB	= 1
LIMIT_HTTPD	= 1

MARGS		= BACKUP_DIR=$(BACKUP_DIR) BACKUP_DB=$(BACKUP_DB) LIMIT_HTTPD=$(LIMIT_HTTPD)

!OS_SPECIFIC_DEFINES
PRL		= $(PERL) -IInclude
INCLUDES	= -ICartridges -I$(EPAGES_CARTRIDGES)
!ifdef WINDOWS
IF_EXIST	= if exist
IF_NOT_EXIST	= if not exist
DO		=
RMDIR		= rmdir /S /Q
DIFF		= gdiff
CHANGE_ETC	= 0
MAKE		= nmake -nologo $(MARGS)
!else
IF_EXIST	= [ ! -e
IF_NOT_EXIST	= [ -e
DO		= ] ||
RMDIR		= rm -rf
DIFF		= diff
EPAGES_PROJECT	?= epages6
CHANGE_ETC	= 1
EPAGES_ETC	= $(shell dirname "$(EPAGES)")\etc
MAKE		= make $(MARGS)
!endif

!ifdef INITIAL_VERSION_LT_6010000000
LOOP_STORES	= $(PRL) Scripts/LoopStores-6.10.0.pl
SYBASE_DUMPS 	= $(PRL) $(INCLUDES) Scripts/DatabaseDumps-6.10.0.pl
!else
LOOP_STORES	= $(PRL) Scripts/LoopStores.pl
SYBASE_DUMPS 	= $(PRL) $(INCLUDES) _CARTRIDGES_/DE_EPAGES/Database/Scripts/DatabaseDumps.pl
!endif
MOVE_DIR	= use DE_EPAGES::Core::API::File qw(RenameDirectory); RenameDirectory
!ifdef INITIAL_VERSION_LT_6011000000
!ifndef INITIAL_VERSION_LT_6012001000
MYSQL_DUMPS 	= $(PRL) $(INCLUDES) Scripts/MySQLDumps.pl
!else
MYSQL_DUMPS 	= $(PRL) $(INCLUDES) _CARTRIDGES_/DE_EPAGES/Database/Scripts/MySQLDumps.pl
!endif
!else
MYSQL_DUMPS 	= $(PRL) $(INCLUDES) _CARTRIDGES_/DE_EPAGES/Database/Scripts/MySQLDumps.pl
!endif
START_SERVICE   = $(PRL) _CARTRIDGES_/DE_EPAGES/Installer/Scripts/startService.pl -ifexists
STOP_SERVICE    = $(PRL) _CARTRIDGES_/DE_EPAGES/Installer/Scripts/stopService.pl -ifexists
CREATE_CTMPLS   = $(PRL) _CARTRIDGES_/DE_EPAGES/Presentation/Scripts/createCtmpls.pl
PATCH_CARTRIDGE_DIRS = _CARTRIDGES_\DE_EPAGES\Installer\Scripts\patchAllCartridgeDirectories.pl
STOREREDIRECT   = $(PRL) $(INCLUDES) _CARTRIDGES_/DE_EPAGES/Database/Scripts/redirectStoreConnections.pl

DOC_CHANGES	= Doc/API/DE_EPAGES Doc/Help/en/MBO Doc/Help/de/MBO Doc/Help/fr/MBO Doc/Help/es/MBO Doc/Help/es/ConfianzaOnline

!ifeq ("$(PATCH_LEVEL)", "0")
SINGLE_HOST_DUMP =
!else
SINGLE_HOST_DUMP = -all
!endif

STORE		= dummy

.force:

# we always need following target for patch.pl:
get_var: .force
	@echo LOG_DIR=$(LOG_DIR)
	@echo BACKUP_DIR=$(BACKUP_DIR)
	@echo TGT_DIR=$(DATA_DIR)\tgt
	@echo TGT=$(TGT)

# how to install the epages patch (see install_en.txt)
# ****************************************************
#-------------------------------------------------------------------------------------------
#    | execute                             | on  UNIX                  | on Windows        |
#-------------------------------------------------------------------------------------------
# 1. | set environment                     | . /etc/default/epages6    |                   |
# 2. | create makefile (needs epages perl) | perl Makefile.PL          | perl Makefile.PL  |
# 3. | pre-installation tasks              | make preinstall           | nmake preinstall  |
# 4. | set environment                     | . /etc/default/epages6    |                   |
# 5. | installation tasks* (see NOTE)      | make install              | nmake install     |
#-------------------------------------------------------------------------------------------
# *) if epages runs on more than 1 computer, execute this step only on your main application server

prepare: $(DATA_DIR)\tgt\prepare
$(DATA_DIR)\tgt\prepare:
	$(MAKE) acl preinstall_storetypes
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)

preinstall: $(TGT)\preinstall
$(TGT)\preinstall:
	$(MAKE) stop_epages limit_httpd stop_cron initial_backup_db
	$(DEL) $(DATA_DIR)\tgt\posthosts.txt
	$(AWK) "/^$(HOSTNAME)$$/{i=1}END{exit i!=1}" $(DATA_DIR)\tgt\prehosts.txt 2>$(NUL) || echo $(HOSTNAME)>> $(DATA_DIR)\tgt\prehosts.txt
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)

install: $(DATA_DIR)\tgt\prepare $(TGT)\preinstall patch_files restart_epages patch update_ctmpls
	echo $(HOSTNAME)> $(DATA_DIR)\tgt\alphahost.txt
	$(IF_EXIST) $(TGT)\restore_style $(DO) $(RMDIR) $(TGT)\restore_style
	$(MAKE) touch DIR=$(DATA_DIR)\tgt ADDF=install DELF=restore
	$(PERL) -MFile::Compare -e "exit not compare('$(DATA_DIR)\tgt\alphahost.txt','$(DATA_DIR)\tgt\prehosts.txt')"\
 || $(MAKE) postinstall IS_ALPHA=1 POSTINSTALL_COMPLETE=1
	$(MAKE) perm INITIAL_VERSION_LT_6010000000=

postinstall:
!ifdef IS_ALPHA
!ifneq ("$(POSTINSTALL_COMPLETE)", "1")
	@echo "Postinstall on alpha server failed: First postinstall all other servers."
	@$(PERL) -e "exit 1;"
!endif
!else
	$(MAKE) acl patch_files
	$(MAKE) perm INITIAL_VERSION_LT_6010000000=
!endif
	$(MAKE) $(DATA_DIR)\tgt\install final_backup_db start_cron new/unlimit_httpd start_epages configure_apache CONFIGURE_HTTPD=1
!ifdef IS_ALPHA
	$(MAKE) open_stores
	$(MAKE) sync_stores
	$(PRL) Scripts/findOverloadedTemplates.pl -store all -patchdir .
!endif
	echo $(HOSTNAME)>> $(DATA_DIR)\tgt\posthosts.txt

# how to restore the prevoius epages version (see install_en.txt)
# ***************************************************************
#-------------------------------------------------------------------------------------------
#    | execute                             | on  UNIX                  | on Windows        |
#-------------------------------------------------------------------------------------------
# 1. | set environment                     | . /etc/default/epages6    |                   |
# 2. | create makefile (needs epages perl) | perl Makefile.PL          | perl Makefile.PL  |
# 3. | pre-restore tasks                   | make prerestore           | nmake prerestore  |
# 4. | restore tasks* (see NOTE)           | make restore              | nmake restore     |
# 5. | set environment                     | . /etc/default/epages6    |                   |
#-------------------------------------------------------------------------------------------
# *) if epages runs on more than 1 computer, execute this step only on your main application server

prerestore:
	$(MAKE) acl INITIAL_VERSION_LT_6010000000=
	$(MAKE) stop_epages restore_files new/limit_httpd stop_cron restart_epages restore_db

restore: prerestore
	$(IF_EXIST) $(TGT)\patch_store $(DO) $(RMDIR) $(TGT)\patch_store
	$(IF_EXIST) $(TGT)\sync_store $(DO) $(RMDIR) $(TGT)\sync_store
	$(IF_EXIST) $(TGT)\test_style $(DO) $(RMDIR) $(TGT)\test_style
	$(IF_EXIST) $(TGT)\create_ctmpl $(DO) $(RMDIR) $(TGT)\create_ctmpl
	$(IF_EXIST) $(TGT)\update_ctmpl $(DO) $(RMDIR) $(TGT)\update_ctmpl
	$(MAKE) update_ctmpls DEL_SAVED_INCLUDES=1
	$(IF_EXIST) $(TGT)\update_ctmpl $(DO) $(RMDIR) $(TGT)\update_ctmpl
	$(MAKE) start_epages
	$(MAKE) restore_styles
	$(MAKE) start_cron
	$(MAKE) touch DIR=$(DATA_DIR)\tgt ADDF=restore DELF=install
	$(MAKE) postrestore perm IS_ALPHA=1

postrestore: $(DATA_DIR)\tgt\restore
	$(DEL) $(TGT)\preinstall
	$(DEL) $(DATA_DIR)\tgt\prehosts.txt
	$(DEL) $(DATA_DIR)\tgt\alphahost.txt
!ifdef IS_ALPHA
	$(MAKE) open_stores
!else
	$(MAKE) start_cron start_epages
!endif
	$(MAKE) unlimit_httpd
	$(IF_EXIST) $(TGT)\sync_store $(DO) $(RMDIR) $(TGT)\sync_store

# main targets (patch files)
# ==========================

patch_files:
!ifeq ("$(CHANGE_CONFIG)", "1")
	$(MAKE) Config\patch
!endif
!ifeq ("$(CHANGE_CARTRIDGES)", "1")
	$(MAKE) Cartridges\patch
!endif
!ifeq ("$(CHANGE_APACHE)", "1")
	$(MAKE) patch_apache
!endif
!ifeq ("$(PATCH_LEVEL)", "0")
!ifeq ("$(CHANGE_PERL)", "1")
	$(MAKE) Perl\patch
!endif
!ifeq ("$(CHANGE_SYBASE)", "1")
	$(MAKE) Sybase\patch
!endif
!ifeq ("$(CHANGE_SERVICE)", "1")
	$(MAKE) Service\patch
!endif
!ifeq ("$(CHANGE_REQROUTER)", "1")
	$(MAKE) RequestRouter\patch
!endif
!ifeq ("$(CHANGE_ETC)", "1")
	$(MAKE) etc\patch
!endif
!ifeq ("$(CHANGE_WEBADAPTER)", "1")
	$(MAKE) WebAdapter\patch
!endif
!endif
!ifeq ("$(CHANGE_BIN)", "1")
	$(MAKE) bin\patch
!endif
!ifeq ("$(CHANGE_WEBROOT)", "1")
	$(MAKE) WebRoot\patch
!endif
!ifeq ("$(CHANGE_STORES)", "1")
	$(PRL) Scripts/patch_shared.pl -cp Stores -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	$(DEL) "$(EPAGES_STORES)"\.$(PATCH_VERSION)-restore
	$(MAKE) touch DIR="$(EPAGES_STORES)" ADDF=.$(PATCH_VERSION)-patch
!ifndef WINDOWS
	chmod 640 "$(EPAGES_STORES)"/.$(PATCH_VERSION)-patch
	chown $${EPAGES_APPUSER:-eprunapp}:epages "$(EPAGES_STORES)"/.$(PATCH_VERSION)-patch
!endif
!endif

restore_files:
!ifeq ("$(PATCH_LEVEL)", "0")
!ifeq ("$(CHANGE_PERL)", "1")
	$(MAKE) Perl\restore
!endif
!ifeq ("$(CHANGE_SYBASE)", "1")
	$(MAKE) Sybase\restore
!endif
!ifeq ("$(CHANGE_SERVICE)", "1")
	$(MAKE) Service\restore
!endif
!ifeq ("$(CHANGE_REQROUTER)", "1")
	$(MAKE) RequestRouter\restore
!endif
!ifeq ("$(CHANGE_WEBADAPTER)", "1")
	$(MAKE) WebAdapter\restore
!endif
!ifeq ("$(CHANGE_ETC)", "1")
	$(MAKE) etc\restore
!endif
!endif
!ifeq ("$(CHANGE_BIN)", "1")
	$(MAKE) bin\restore
!endif
!ifeq ("$(CHANGE_WEBROOT)", "1")
	$(MAKE) WebRoot\restore
!endif
!ifeq ("$(CHANGE_STORES)", "1")
	$(MAKE) Stores\restore
!endif
!ifeq ("$(CHANGE_CONFIG)", "1")
	$(MAKE) Config\restore
!endif
!ifeq ("$(CHANGE_CARTRIDGES)", "1")
	$(MAKE) Cartridges\restore
!endif

# main targets (patch database)
# =============================

# backup databases
initial_backup_db: $(TGT)\initial_backup_db
final_backup_db: $(TGT)\final_backup_db
$(TGT)\initial_backup_db $(TGT)\final_backup_db full_backup_db:
!ifneq ("$(BACKUP_DB)", "")
!ifeq ("$(MYSQL_DATASOURCE)", "1")
	$(MYSQL_DUMPS) $(SINGLE_HOST_DUMP) -target $@
!endif
!ifeq ("$(SYBASE_DATASOURCE)", "1")
!ifdef INITIAL_VERSION_LT_6010000000
	$(SYBASE_DUMPS) $(SINGLE_HOST_DUMP) -action $@ -ini database.ini
!else
	$(SYBASE_DUMPS) $(SINGLE_HOST_DUMP) -target $@
!endif
!endif
!endif

# install the patch
patch: patch_site patch_stores patch_pooldb patch_version

# restore databases
restore_db: $(TGT)\restore_db
$(TGT)\restore_db:
!ifneq ("$(BACKUP_DB)", "")
!ifeq ("$(SYBASE_RUNS)", "1")
!ifndef WINDOWS
!ifneq ("$(EXECUTOR)", "root")
	-$(ETC_INITD) perm sybase -u
!endif
!endif
!ifdef INITIAL_VERSION_LT_6010000000
	$(SYBASE_DUMPS) -own -action $@ -ini database.ini
!else
	$(SYBASE_DUMPS) -target $@
!endif
!endif
!ifeq ("$(MYSQL_DATASOURCE)", "1")
!ifndef INITIAL_VERSION_LT_6010000000
	$(MYSQL_DUMPS) -own -target $@
!else
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=initial_backup_db
	$(DEL) $(@D)\final_backup_db
!endif
!else
!ifneq ("$(SYBASE_RUNS)", "1")
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=initial_backup_db
	$(DEL) $(@D)\final_backup_db
!endif
!endif
!endif

# targets (patch files)
# *********************

# patch: etc

etc\patch: $(EPAGES_ETC)\.$(PATCH_VERSION)-patch
$(EPAGES_ETC)\.$(PATCH_VERSION)-patch:
!ifdef INITIAL_VERSION_LT_6010000000
	[ ! -d "$(EPAGES_SHARED)\etc" ] || $(PRL) Scripts/patch_files.pl -patch Shared/etc -backupall "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	[ ! -d "$(EPAGES_SHARED)\etc" ] || rm -rf $(EPAGES_SHARED)\etc
!endif
	$(PRL) Scripts/patch_files.pl -patch etc -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	chmod 755 ./Scripts/patch_etc.sh
	./Scripts/patch_etc.sh -P "$(EPAGES_PROJECT)" -i "$(INITIAL_INTERNAL_VERSION)" -p $(PATCH_TAG) -b "$(BACKUP_DIR)"

etc\restore: $(EPAGES_ETC)\.$(PATCH_VERSION)-restore
$(EPAGES_ETC)\.$(PATCH_VERSION)-restore:
!ifdef INITIAL_VERSION_LT_6010000000
	[ ! -d "$(BACKUP_DIR)\Shared\etc" ] || $(PRL) Scripts/patch_files.pl -restore Shared\etc -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif
	$(PRL) Scripts/patch_files.pl -restore etc -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	chmod 755 ./Scripts/patch_etc.sh
	./Scripts/patch_etc.sh -R -P "$(EPAGES_PROJECT)" -i "$(INITIAL_INTERNAL_VERSION)" -p $(PATCH_TAG) -b "$(BACKUP_DIR)"

# patch: bin

bin\patch: $(EPAGES)\bin\.$(PATCH_VERSION)-patch
$(EPAGES)\bin\.$(PATCH_VERSION)-patch:
!ifdef WINDOWS
	$(PRL) Scripts/patch_files.pl -patch bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!else
	$(PRL) Scripts/patch_files.pl -patch bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!ifdef INITIAL_VERSION_LT_6010000000
	$(DEL) "$(EPAGES)"\bin\tar.exe
	$(DEL) "$(EPAGES)"\bin\gzip.exe
!endif
!endif
!ifdef INITIAL_VERSION_LT_6009001000
	$(IF_EXIST) "$(EPAGES)"\bin\bin $(DO) $(RMDIR) "$(EPAGES)"\bin\bin
!endif

bin\restore: $(EPAGES)\bin\.$(PATCH_VERSION)-restore
$(EPAGES)\bin\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: Service

Service\patch: $(EPAGES)\Service\.$(PATCH_VERSION)-patch
$(EPAGES)\Service\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch Service -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

Service\restore: $(EPAGES)\Service\.$(PATCH_VERSION)-restore
$(EPAGES)\Service\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore Service -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: RequestRouter

RequestRouter\patch: $(EPAGES)\RequestRouter\.$(PATCH_VERSION)-patch
$(EPAGES)\RequestRouter\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch RequestRouter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

RequestRouter\restore: $(EPAGES)\RequestRouter\.$(PATCH_VERSION)-restore
$(EPAGES)\RequestRouter\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore RequestRouter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: WebAdapter

WebAdapter\patch: $(EPAGES)\WebAdapter\.$(PATCH_VERSION)-patch
$(EPAGES)\WebAdapter\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch WebAdapter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!ifndef WINDOWS
	cat linux/WebAdapter/zzz-epages-httpd.conf.ept > "$(EPAGES)"/WebAdapter/zzz-epages-httpd.conf.ept
!endif

WebAdapter\restore: $(EPAGES)\WebAdapter\.$(PATCH_VERSION)-restore
$(EPAGES)\WebAdapter\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore WebAdapter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: Cartridges

Cartridges\patch: $(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-patch
$(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-patch:
	$(MAKE) close_stores
!ifeq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/patch_shared.pl -cp Cartridges -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -consider CPAN
	$(PRL) Scripts/patch_files.pl -patch Cartridges -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -ignore CPAN
!else
	$(PRL) Scripts/patch_files.pl -patch Cartridges -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif
!ifneq ("$(BACKUP_DIR)", "")
	$(MKDIR) "$(BACKUP_DIR)\Cartridges"
!ifdef WINDOWS
	$(CP) "$(EPAGES_CARTRIDGES)"\Cartridges.xml "$(BACKUP_DIR)\Cartridges"\Cartridges.xml
!else
	cp -p "$(EPAGES_CARTRIDGES)"\Cartridges.xml "$(BACKUP_DIR)\Cartridges"\Cartridges.xml
!endif
!endif
	$(MAKE) make_makefile
	$(PRL) Scripts/patchCartrigesXML.pl
	$(PRL) $(PATCH_CARTRIDGE_DIRS) ALL

Cartridges\restore: $(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-restore
$(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-restore:
	$(MAKE) close_stores
	$(PRL) Scripts/patch_shared.pl -rm Cartridges -version $(PATCH_VERSION)
	$(PRL) Scripts/patch_files.pl -restore Cartridges -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: Perl

Perl\patch: $(EPAGES_PERL)\.$(PATCH_VERSION)-patch
$(EPAGES_PERL)\.$(PATCH_VERSION)-patch:
!ifeq ("$(PATCH_LEVEL)", "0")
	$(PRL) _CARTRIDGES_/DE_EPAGES/Installer/Scripts/installCPAN.pl CPAN::EPAGES
!endif
!ifdef INITIAL_VERSION_LT_6011000000
!ifndef WINDOWS
	$(COPY_DIR) $(OSNAME)\Perl\lib $(EPAGES_PERL)\lib
!ifneq ("$(BACKUP_DIR)", "")
	$(MKDIR) "$(BACKUP_DIR)/Perl"
	[ ! -d $(EPAGES_PERL)/.gpg ] || mv $(EPAGES_PERL)/.gpg "$(BACKUP_DIR)/Perl/.gpg"
!endif
!endif
!endif
!ifdef INITIAL_VERSION_LT_6010000000
!ifdef WINDOWS
	$(DEL) $(EPAGES_PERL)\site\lib\auto\Clone\Clone.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\DBD\SQLite\SQLite.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\DBD\Sybase\Sybase.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\Devel\NYTProf\NYTProf.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\List\MoreUtils\MoreUtils.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\Params\Util\Util.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\Socket6\Socket6.pdb
	$(DEL) $(EPAGES_PERL)\site\lib\auto\Win32\Process\Process.pdb
	$(IF_EXIST) $(EPAGES_PERL)\lib\Test\Builder $(DO) $(RMDIR) $(EPAGES_PERL)\lib\Test\Builder
	$(DEL) $(EPAGES_PERL)\lib\Test\Builder.pm
	$(DEL) $(EPAGES_PERL)\lib\Test\More.pm
	$(DEL) $(EPAGES_PERL)\lib\Test\Simple.pm
	$(DEL) $(EPAGES_PERL)\lib\Test\Tutorial.pod
	$(CP) $(OSNAME)\Perl\bin\libmysql.dll $(EPAGES_PERL)\bin\libmysql.dll
!else
	find $(EPAGES_PERL)\lib\site_perl\linux\auto -name "*.so" -exec chmod 755 {} ";"
	[ -d $(EPAGES_PERL)\lib32 ] || { cp -rp $(OSNAME)\Perl\lib32 $(EPAGES_PERL);\
 chown -R ep_appl:epages $(EPAGES_PERL)\lib32; }
!endif
!endif
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=.$(PATCH_VERSION)-restore

Perl\restore: $(EPAGES_PERL)\.$(PATCH_VERSION)-restore
$(EPAGES_PERL)\.$(PATCH_VERSION)-restore:
!ifdef INITIAL_VERSION_LT_6011000000
!ifndef WINDOWS
!ifneq ("$(BACKUP_DIR)", "")
	[ ! -d "$(BACKUP_DIR)/Perl/.gpg" ] || $(COPY_DIR) "$(BACKUP_DIR)/Perl/.gpg" $(EPAGES_PERL)/.gpg
!endif
!endif
!endif
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=.$(PATCH_VERSION)-patch

# patch: Apache

patch_apache:
!ifndef WINDOWS
!ifdef INITIAL_VERSION_LT_6010002000
	if cd $(EPAGES)/Apache/bin ; then [ ! -f httpd ] || cp -p httpd httpd.sh ; fi
	cat $(OSNAME)/Apache/bin/httpd.sh > $(EPAGES)/Apache/bin/httpd.sh
!endif
!endif

# patch: Sybase

Sybase\patch: $(EPAGES)\Sybase\.$(PATCH_VERSION)-patch
$(EPAGES)\Sybase\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch Sybase\bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

Sybase\restore: $(EPAGES)\Sybase\.$(PATCH_VERSION)-restore
$(EPAGES)\Sybase\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore Sybase\bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: WebRoot

WebRoot\patch: $(EPAGES_WEBROOT)\.$(PATCH_VERSION)-patch
$(EPAGES_WEBROOT)\.$(PATCH_VERSION)-patch:
!ifdef CONSIDER_DOC_CHANGES
	$(PRL) Scripts/patch_shared.pl -cp WebRoot -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -consider "$(DOC_CHANGES)"
!endif
!ifdef INITIAL_VERSION_LT_6010003000
	$(PRL) Scripts/cleanWebrootForStoreTypeChanges.pl -backup "$(BACKUP_DIR)"
!endif
	$(PRL) Scripts/patch_files.pl -patch WebRoot -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -ignore "$(DOC_CHANGES)"
!ifeq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/patch_files.pl -patch Monitor -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif
!ifdef INITIAL_VERSION_LT_6011000000
!ifndef WINDOWS
	chmod -R 750 $(EPAGES_SHARED)/Monitor
!endif
!endif

WebRoot\restore: $(EPAGES_WEBROOT)\.$(PATCH_VERSION)-restore
$(EPAGES_WEBROOT)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_shared.pl -rm WebRoot -version $(PATCH_VERSION)
!ifdef INITIAL_VERSION_LT_6010000000
	$(IF_EXIST) $(EPAGES_WEBROOT)\Doc\Help\de\BBO $(DO) $(RMDIR) $(EPAGES_WEBROOT)\Doc\Help\de\BBO
	$(IF_EXIST) $(EPAGES_WEBROOT)\Doc\Help\de\MBO $(DO) $(RMDIR) $(EPAGES_WEBROOT)\Doc\Help\de\MBO
	$(IF_EXIST) $(EPAGES_WEBROOT)\Doc\Help\de\TBO $(DO) $(RMDIR) $(EPAGES_WEBROOT)\Doc\Help\de\TBO
	$(IF_EXIST) $(EPAGES_WEBROOT)\Doc\Help\en\BBO $(DO) $(RMDIR) $(EPAGES_WEBROOT)\Doc\Help\en\BBO
	$(IF_EXIST) $(EPAGES_WEBROOT)\Doc\Help\en\MBO $(DO) $(RMDIR) $(EPAGES_WEBROOT)\Doc\Help\en\MBO
	$(IF_EXIST) $(EPAGES_WEBROOT)\Doc\Help\en\TBO $(DO) $(RMDIR) $(EPAGES_WEBROOT)\Doc\Help\en\TBO
!endif
	$(PRL) Scripts/patch_files.pl -restore WebRoot -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha "$(IS_ALPHA)"
!ifdef INITIAL_VERSION_LT_6010002000
	$(IF_EXIST) "$(EPAGES_WEBROOT)\StoreTypes" $(DO) $(RMDIR) "$(EPAGES_WEBROOT)\StoreTypes"
!else
	$(IF_EXIST) "$(EPAGES_WEBROOT)\StoreTypes\$(PATCH_VERSION)" $(DO) $(RMDIR) "$(EPAGES_WEBROOT)\StoreTypes\$(PATCH_VERSION)"
	$(DEL) $(DATA_DIR)\tgt\preinstall_storetypes
	$(DEL) $(DATA_DIR)\tgt\prepare
!endif
!ifeq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/patch_files.pl -restore Monitor -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif
!ifdef INITIAL_VERSION_LT_6011000000
!ifndef WINDOWS
	chmod -R 770 $(EPAGES_SHARED)/Monitor
!endif
!endif

# patch: Stores

Stores\restore: $(EPAGES_STORES)\.$(PATCH_VERSION)-restore
$(EPAGES_STORES)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_shared.pl -rm Stores -version $(PATCH_VERSION)
	$(PRL) Scripts/patch_files.pl -restore Stores -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha "$(IS_ALPHA)"

# patch: Config

Config\patch: $(EPAGES_CONFIG)\.$(PATCH_VERSION)-patch
$(EPAGES_CONFIG)\.$(PATCH_VERSION)-patch:
!ifdef SYBASE_LICENSE
	$(PRL) Scripts/patch_files.pl -md5sum md5sum.ini -patch Config -backupall "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha 0
	$(PRL) Scripts/patch_files.pl -md5sum md5sum.ini -patch SYBASE/Config -version $(PATCH_VERSION)
!else
	$(PRL) Scripts/patch_files.pl -md5sum md5sum.ini -patch Config -backupall "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif
!ifdef INITIAL_VERSION_LT_6010000000
	$(PRL) Scripts/EditDatabaseConf.pl -ini database.ini
!endif
!ifdef INITIAL_VERSION_LT_6010002000
	$(PRL) Scripts/EditDatabaseD.pl -version $(PATCH_VERSION)
!endif
!ifdef INITIAL_VERSION_LT_6010004000
	$(PRL) Scripts/ConfigureMailDebug.pl
!endif

Config\restore: $(EPAGES_CONFIG)\.$(PATCH_VERSION)-restore
$(EPAGES_CONFIG)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore Config -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha "$(IS_ALPHA)"
!ifdef INITIAL_VERSION_LT_6010000000
	$(IF_EXIST) $(EPAGES_CONFIG)\Database.d $(DO) $(RMDIR) $(EPAGES_CONFIG)\Database.d
!endif
!ifdef INITIAL_VERSION_LT_6010002000
!ifndef INITIAL_VERSION_LT_6010000000
	$(IF_EXIST) $(EPAGES_CONFIG)\Cartridges.d $(DO) $(RMDIR) $(EPAGES_CONFIG)\Cartridges.d
!endif
!endif
!ifdef INITIAL_VERSION_LT_6010003000
	$(IF_EXIST) $(EPAGES_CONFIG)\StoreTypes.d $(DO) $(RMDIR) $(EPAGES_CONFIG)\StoreTypes.d
!else
	$(IF_EXIST) "$(EPAGES_CONFIG)\StoreTypes.d\$(PATCH_VERSION)" $(DO) $(RMDIR) "$(EPAGES_CONFIG)\StoreTypes.d\$(PATCH_VERSION)"
!endif

# targets (patch database)
# ************************

close_stores: loop_stores.mak
	$(MAKE) make_makefile
!ifndef EPAGES_IGNORE_SITE
!ifdef INITIAL_VERSION_LT_6010001000
	$(STOREREDIRECT) -storename Site -redirect StoreClosed.html
!else
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) close_store STORE=Site STORE_TYPE=Site
!endif
!endif
	$(MAKE) -f loop_stores.mak close_stores TGT="$(TGT)"
close_store:
!ifdef INITIAL_VERSION_LT_6010001000
	$(STOREREDIRECT) -storename $(STORE) -redirect StoreClosed.html
!else
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) close_store STORE=$(STORE) STORE_TYPE=$(STORE_TYPE)
!endif
	$(DEL) $(TGT)\open_store\$(STORE)

open_stores: loop_stores.mak
	$(MAKE) make_makefile
!ifndef EPAGES_IGNORE_SITE
	$(STOREREDIRECT) -storename Site -remove
!ifdef INITIAL_VERSION_LT_6010001000
!else
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) open_store STORE=Site STORE_TYPE=Site
!endif
!endif
	$(MAKE) -f loop_stores.mak open_stores TGT="$(TGT)"
open_store:
!ifdef INITIAL_VERSION_LT_6010001000
	$(STOREREDIRECT) -storename $(STORE) -remove
!else
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) open_store STORE=$(STORE) STORE_TYPE=$(STORE_TYPE)
!endif
	$(DEL) $(TGT)\close_store\$(STORE)

preinstall_storetypes: $(DATA_DIR)\tgt\preinstall_storetypes
$(DATA_DIR)\tgt\preinstall_storetypes:
!ifeq ("$(STORES_OK)", "1")
	$(PRL) Scripts/MergeDataPublic.pl -initial "$(INITIAL_INTERNAL_VERSION)" -target "$(DATA_DIR)" 2> Scripts\set_cartridge_dir
!ifdef INITIAL_VERSION_LT_6010000000
	$(PRL) $(INCLUDES) Scripts/EditDatabaseConf.pl -ini database.ini -conf "$(DATA_DIR)\Config"
!endif
!ifdef INITIAL_VERSION_LT_6010002000
	$(PRL) $(INCLUDES) Scripts/EditDatabaseD.pl -version $(PATCH_VERSION) -conf "$(DATA_DIR)\Config"
!endif
	$(MAKE) build_plx NAME=patchCartrigesXML SCRIPT=Scripts/patchCartrigesXML.pl
	$(MAKE) build_plx NAME=patchAllCartridgeDirectories SCRIPT=$(PATCH_CARTRIDGE_DIRS)
	$(MAKE) build_plx NAME=installStoreType SCRIPT=_CARTRIDGES_\DE_EPAGES\Installer\Scripts\installStoreType.pl
	$(MAKE) build_plx NAME=DictionaryConverter SCRIPT=_CARTRIDGES_\DE_EPAGES\JQuery\Scripts\DictionaryConverter.pl
	$(PRL) $(INCLUDES) Scripts/patchCartrigesXML.plx
	$(PRL) $(INCLUDES) Scripts/patchAllCartridgeDirectories.plx ALL
	$(PRL) $(INCLUDES) Scripts/installStoreType.plx ALL -storetype all -version $(PATCH_VERSION)
!ifdef INITIAL_VERSION_LT_6010002000
	$(MKDIR) $(EPAGES_CONFIG)\StoreTypes.d
	$(COPY_DIR) "$(DATA_DIR)\Config\StoreTypes.d\$(PATCH_VERSION)" $(EPAGES_CONFIG)\StoreTypes.d\$(PATCH_VERSION)
!endif
	$(PRL) $(INCLUDES) Scripts/SetStoreTypeLanguages.pl -version $(PATCH_VERSION) -lang "$(LANGUAGES_STORETYPE)"
	$(PRL) $(INCLUDES) Scripts/DictionaryConverter.plx -cartridge ALL -storetype all -version $(PATCH_VERSION)
	$(MAKE) run_plx NAME=buildDojo SCRIPT=_CARTRIDGES_\DE_EPAGES\Dojo\Scripts\build.pl
	$(MAKE) run_plx NAME=buildJS   SCRIPT=_CARTRIDGES_\DE_EPAGES\Presentation\Scripts\buildJS.pl
	$(MAKE) run_plx NAME=buildCSS  SCRIPT=_CARTRIDGES_\DE_EPAGES\Presentation\Scripts\buildCSS.pl
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)
!endif

build_plx:
	$(COPY_FILE) Scripts/set_cartridge_dir Scripts/$(NAME).plx
	$(CAT) $(SCRIPT) >> Scripts/$(NAME).plx

run_plx:
	$(MAKE) build_plx
	$(PRL) $(INCLUDES) Scripts/$(NAME).plx -storetype all -version $(PATCH_VERSION)

patch_site:
!ifndef EPAGES_IGNORE_SITE
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) patch_store STORE=Site STORE_TYPE=Site
!endif
!ifdef INITIAL_VERSION_LT_6010000000
	$(PRL) $(DE_EPAGES_DIR)/Object/Scripts/deleteObject.pl -nosync -storename Site -path /FeatureRefs/Invoice
	$(PRL) $(DE_EPAGES_DIR)/Object/Scripts/deleteObject.pl -nosync -storename Site -path /FeatureRefs/PackingSlip
	$(PRL) $(DE_EPAGES_DIR)/Object/Scripts/deleteObject.pl -nosync -storename Site -path /FeatureRefs/CreditNote
!endif

patch_stores: loop_stores.mak
	$(MAKE) -f loop_stores.mak patch_stores TGT="$(TGT)"
!ifdef INITIAL_VERSION_LT_6010003000
!ifneq ("$(BACKUP_DIR)", "")
	$(PRL) -e "$(MOVE_DIR)('$(DE_EPAGES_DIR)\TPay','$(BACKUP_DIR)\Cartridges\DE_EPAGES\TPay',{create_directory=>1,stat=>preserve});"
!else
	$(IF_EXIST) $(DE_EPAGES_DIR)\TPay $(DO) $(RMDIR) $(DE_EPAGES_DIR)\TPay
!endif
!endif
patch_store:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) patch_store STORE=$(STORE) STORE_TYPE=$(STORE_TYPE)
!ifdef INITIAL_VERSION_LT_6010003000
	$(PRL) Scripts/UninstallIfExists.pl -cartridge DE_EPAGES::TPay -storename $(STORE)
!endif

patch_pooldb:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) patch_store STORE=ASPoolDB STORE_TYPE=ASPoolDB DOJOBUILD=0

sync_stores: loop_stores.mak
!ifndef EPAGES_IGNORE_SITE
	$(MAKE) sync_store STORE=Site
!endif
	$(MAKE) -f loop_stores.mak sync_stores TGT="$(TGT)"
sync_store:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) synchronize STORE=$(STORE)

restore_styles: loop_stores.mak
	$(MAKE) -f loop_stores.mak restore_styles TGT="$(TGT)"
restore_style:
	$(PRL) _CARTRIDGES_/DE_EPAGES/Design/Scripts/invalidateAllStyles.pl -storename $(STORE)

create_ctmpls: loop_stores.mak
!ifndef EPAGES_IGNORE_SITE
	$(CREATE_CTMPLS) -storename Site -nooutput
!endif
	$(MAKE) -f loop_stores.mak create_ctmpls TGT="$(TGT)"
create_ctmpl:
	$(CREATE_CTMPLS) -storename $(STORE) -nooutput

update_ctmpls: loop_stores.mak
!ifndef EPAGES_IGNORE_SITE
!ifdef CTMPL_TXT
	$(CREATE_CTMPLS) -storename Site -listfile ctmpl-Site.txt -nooutput
!else
	$(CREATE_CTMPLS) -storename Site -delete -nooutput
!endif
!ifdef DEL_SAVED_INCLUDES
	$(IF_EXIST) $(EPAGES_STATIC)\Site\SavedIncludes $(DO) $(RMDIR) $(EPAGES_STATIC)\Site\SavedIncludes
!endif
!endif
	$(MAKE) -f loop_stores.mak update_ctmpls TGT="$(TGT)"
update_ctmpl:
!ifdef CTMPL_TXT
	$(CREATE_CTMPLS) -storename $(STORE) -listfile ctmpl-$(STORE).txt -nooutput
!else
	$(CREATE_CTMPLS) -storename $(STORE) -delete -nooutput
!endif
!ifdef DEL_SAVED_INCLUDES
	$(IF_EXIST) $(EPAGES_STATIC)\$(STORE)\SavedIncludes $(DO) $(RMDIR) $(EPAGES_STATIC)\$(STORE)\SavedIncludes
!endif

test_styles: loop_stores.mak
	$(MAKE) -f loop_stores.mak test_styles TGT="$(TGT)"
test_style:
	$(PRL) _CARTRIDGES_/DE_EPAGES/Installer/Scripts/compareCartridgeData.pl -storename $(STORE) -type $(STORE_TYPE)

make_makefile:
	$(CD) $(DE_EPAGES_DIR) && $(PRL) Makefile.PL

loop_stores.mak:
!ifdef INITIAL_VERSION_LT_6010000000
	$(LOOP_STORES) -mak makefile -ini database.ini> $@.out
!else
	$(LOOP_STORES) -mak makefile> $@.out
!endif
	$(MOVE) $@.out $@

patch_version:
!ifdef INITIAL_VERSION_LT_6010000000
	$(PRL) Scripts/MoveDir.pl "$(EPAGES_CARTRIDGES)\COM_LEGUIDE" "$(BACKUP_DIR)\Cartridges\COM_LEGUIDE"
!ifneq ("$(MYSQL_DATASOURCE)", "1")
	$(PRL) Scripts/disableMySQLScheduler.pl
!endif
!endif
	echo $(PATCH_TAG)>> $(EPAGES_CONFIG)\version.txt

# auxiliary targets
# *****************

stop_cron:
!ifneq ("$(PATCH_LEVEL)", "0")
	$(IF_NOT_EXIST) "$(DATA_DIR)"\tgt\prehosts.txt $(DO) $(PRL) Scripts/EditSchedulerConf.pl -stop $(CRON_FILES)
!endif
	$(MAKE) stop_sic

start_cron:
!ifneq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/EditSchedulerConf.pl -start $(CRON_FILES)
!endif
	$(MAKE) start_sic

start_sic: $(TGT)\start_sic
$(TGT)\start_sic:
!ifeq ("$(CHANGE_SIC)", "1")
	$(START_SIC)
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)
!endif

stop_sic:
!ifeq ("$(CHANGE_SIC)", "1")
	$(STOP_SIC)
	$(DEL) $(TGT)\start_sic
!endif

stop_web:
!ifeq ("$(PATCH_LEVEL)", "0")
!ifdef APACHE_LOCAL
	$(APACHE_STOP)
!else
	$(STOP_SERVICE) webserver
!endif
!ifndef WINDOWS
!BEGIN_VERBATIM
	-kill $$(ps -u$(EPAGES_WEBUSER) -uep_web -opid= -oppid= -ocomm= 2>/dev/null | while read pid ppid comm ;\
 do [ "$${comm#httpd}" != "$$comm" ] && echo -e "$$pid\n$$ppid" ; done | sort | uniq | tr '\n' ' ') 2>/dev/null
!END_VERBATIM
!endif
!endif

start_web:
!ifeq ("$(PATCH_LEVEL)", "0")
!ifdef CONFIGURE_HTTPD
	$(MAKE) configure_httpd
!endif
!ifdef APACHE_LOCAL
	$(APACHE_START)
!else
	$(START_SERVICE) webserver
!endif
!endif

stop_epages: .force stop_web
!ifeq ("$(PATCH_LEVEL)", "0")
	$(STOP_SERVICE) cron
	$(STOP_SERVICE) epages
!ifndef WINDOWS
	if pgrep RequestRouter ; then $(ETC_INITD) stop_rr || pkill -9 RequestRouter ; fi
!endif
!endif

start_epages: .force start_web
!ifeq ("$(PATCH_LEVEL)", "0")
	$(START_SERVICE) epages
	$(START_SERVICE) cron
!endif

restart_epages:
!ifneq ("$(PATCH_LEVEL)", "0")
!ifdef IS_ALPHA
	$(PRL) _CARTRIDGES_/DE_EPAGES/WebInterface/Scripts/shutdownAppSrv.pl -sleep 0
!endif
!endif

limit_httpd unlimit_httpd new/limit_httpd new/unlimit_httpd:
!ifdef LIMIT_HTTPD
!ifdef APACHE_CONF
	chmod 755 ./Apache/$(@F).sh
	./Apache/$(@F).sh -v "$(@D)" -c host-$(HOSTNAME).mk -i "$(INITIAL_INTERNAL_VERSION)"
	$(APACHE_START)
!endif
!endif

configure_httpd:
!ifdef WINDOWS
!ifdef INITIAL_VERSION_LT_6011000000
	cscript Scripts\ConfigureIIS.vbs
!endif
!else
!ifdef APACHE_CONF
	chmod 755 ./Apache/$(@F).sh
	./Apache/$(@F).sh -c host-$(HOSTNAME).mk -i "$(INITIAL_INTERNAL_VERSION)"
!endif
!endif

configure_apache:
!ifdef APACHE_CONF
!ifneq ("$(PATCH_LEVEL)", "0")
	chmod 755 ./Apache/configure_httpd.sh
	./Apache/configure_httpd.sh -c host-$(HOSTNAME).mk -i "$(INITIAL_INTERNAL_VERSION)"
	$(APACHE_START)
!endif
!endif

acl:
!ifdef EPAGES_ACL
!ifndef INITIAL_VERSION_LT_6010000000
!ifneq ("$(EXECUTOR)", "root")
	-$(ETC_INITD) +acl all
!endif
!endif
!endif

perm:
!ifndef WINDOWS
!ifneq ("$(EXECUTOR)", "root")
	-$(ETC_INITD) perm all -u
!endif
!ifdef EPAGES_ACL
!ifdef INITIAL_VERSION_LT_6010000000
	-$(ETC_INITD) perm stores
	-$(ETC_INITD) perm webroot
	-$(ETC_INITD) perm static
	-$(ETC_INITD) perm apache
	-$(ETC_INITD) perm sybase
!else
	-$(ETC_INITD) -acl all
!endif
!endif
	-$(ETC_INITD) perm admin
!endif

touch:
	$(MKDIR) $(DIR)
	$(DEL) $(DIR)\$(DELF)
	$(ECHONL) > $(DIR)\$(ADDF)

del_backup_files:
!ifneq ("$(BACKUP_DIR)", "")
	$(IF_EXIST) "$(BACKUP_DIR)" $(DO) $(RMDIR) "$(BACKUP_DIR)"
!endif
	$(IF_EXIST) "$(DATA_DIR)\tgt" $(DO) $(RMDIR) "$(DATA_DIR)\tgt"
	$(IF_EXIST) "$(DATA_DIR)\Config" $(DO) $(RMDIR) "$(DATA_DIR)\Config"
	$(IF_EXIST) "$(DATA_DIR)\DE_EPAGES" $(DO) $(RMDIR) "$(DATA_DIR)\DE_EPAGES"
	$(DEL) "$(DATA_DIR)\Cartridges.xml"
	$(PRL) Scripts/DeleteOldStoreTypeDirs.pl -current $(PATCH_VERSION)
	$(DEL) $(EPAGES_CARTRIDGES)/.6.*
	$(DEL) $(EPAGES_SHARED)/Monitor/.6.*
	$(DEL) $(EPAGES_STORES)/.6.*
	$(DEL) $(EPAGES_WEBROOT)/.6.*
	$(DEL) $(EPAGES_CONFIG)/.6.*
	$(DEL) $(EPAGES)/Service/.6.*
	$(DEL) $(EPAGES)/RequestRouter/.6.*
	$(DEL) $(EPAGES)/WebAdapter/.6.*
	$(DEL) $(HTTPD_ROOT)/.6.*
	$(DEL) $(EPAGES_PERL)/.6.*
	$(DEL) $(SYBASE)/.6.*
	$(DEL) $(SYBASE)/bin/.6.*
	$(DEL) $(EPAGES)/bin/.6.*
!ifndef WINDOWS
	$(DEL) `dirname $(EPAGES)`/etc/.6.*
!endif

#-*- Makefile -*-
